# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: model/model/v1alpha/model.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from common.healthcheck.v1beta import healthcheck_pb2 as common_dot_healthcheck_dot_v1beta_dot_healthcheck__pb2
from common.run.v1alpha import run_pb2 as common_dot_run_dot_v1alpha_dot_run__pb2
from common.task.v1alpha import task_pb2 as common_dot_task_dot_v1alpha_dot_task__pb2
from core.mgmt.v1beta import mgmt_pb2 as core_dot_mgmt_dot_v1beta_dot_mgmt__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.longrunning import operations_pb2 as google_dot_longrunning_dot_operations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from model.model.v1alpha import common_pb2 as model_dot_model_dot_v1alpha_dot_common__pb2
from model.model.v1alpha import model_definition_pb2 as model_dot_model_dot_v1alpha_dot_model__definition__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fmodel/model/v1alpha/model.proto\x12\x13model.model.v1alpha\x1a+common/healthcheck/v1beta/healthcheck.proto\x1a\x1c\x63ommon/run/v1alpha/run.proto\x1a\x1e\x63ommon/task/v1alpha/task.proto\x1a\x1b\x63ore/mgmt/v1beta/mgmt.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a#google/longrunning/operations.proto\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a model/model/v1alpha/common.proto\x1a*model/model/v1alpha/model_definition.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\"\x95\x01\n\x0fLivenessRequest\x12i\n\x14health_check_request\x18\x01 \x01(\x0b\x32-.common.healthcheck.v1beta.HealthCheckRequestB\x03\xe0\x41\x01H\x00R\x12healthCheckRequest\x88\x01\x01\x42\x17\n\x15_health_check_request\"v\n\x10LivenessResponse\x12\x62\n\x15health_check_response\x18\x01 \x01(\x0b\x32..common.healthcheck.v1beta.HealthCheckResponseR\x13healthCheckResponse\"\x96\x01\n\x10ReadinessRequest\x12i\n\x14health_check_request\x18\x01 \x01(\x0b\x32-.common.healthcheck.v1beta.HealthCheckRequestB\x03\xe0\x41\x01H\x00R\x12healthCheckRequest\x88\x01\x01\x42\x17\n\x15_health_check_request\"w\n\x11ReadinessResponse\x12\x62\n\x15health_check_response\x18\x01 \x01(\x0b\x32..common.healthcheck.v1beta.HealthCheckResponseR\x13healthCheckResponse\"E\n\x06Region\x12\x1f\n\x0bregion_name\x18\x01 \x01(\tR\nregionName\x12\x1a\n\x08hardware\x18\x02 \x03(\tR\x08hardware\"\xdf\x01\n\x0cModelVersion\x12\x17\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x05R\x04name\x12\x1d\n\x07version\x18\x02 \x01(\tB\x03\xe0\x41\x05R\x07version\x12\x1b\n\x06\x64igest\x18\x03 \x01(\tB\x03\xe0\x41\x01R\x06\x64igest\x12\x35\n\x05state\x18\x04 \x01(\x0e\x32\x1a.model.model.v1alpha.StateB\x03\xe0\x41\x03R\x05state\x12\x43\n\x0bupdate_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xe0\x41\x03\xe0\x41\x01R\nupdateTime\"\xd3\r\n\x05Model\x12*\n\x04name\x18\x01 \x01(\tB\x16\x92\x41\x10\xca>\r\xfa\x02\nmodel_name\xe0\x41\x03R\x04name\x12\x15\n\x03uid\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x03uid\x12\x16\n\x02id\x18\x03 \x01(\tB\x06\xe0\x41\x02\xe0\x41\x05R\x02id\x12*\n\x0b\x64\x65scription\x18\x04 \x01(\tB\x03\xe0\x41\x01H\x00R\x0b\x64\x65scription\x88\x01\x01\x12V\n\x10model_definition\x18\x05 \x01(\tB+\xe0\x41\x02\xe0\x41\x05\xfa\x41\"\n api.instill.tech/ModelDefinitionR\x0fmodelDefinition\x12\x45\n\rconfiguration\x18\x06 \x01(\x0b\x32\x17.google.protobuf.StructB\x06\xe0\x41\x02\xe0\x41\x05R\rconfiguration\x12\x35\n\x04task\x18\x07 \x01(\x0e\x32\x19.common.task.v1alpha.TaskB\x06\xe0\x41\x02\xe0\x41\x05R\x04task\x12J\n\nvisibility\x18\t \x01(\x0e\x32%.model.model.v1alpha.Model.VisibilityB\x03\xe0\x41\x02R\nvisibility\x12@\n\x0b\x63reate_time\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12@\n\x0bupdate_time\x18\r \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\nupdateTime\x12@\n\x0b\x64\x65lete_time\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ndeleteTime\x12\"\n\nowner_name\x18\x0f \x01(\tB\x03\xe0\x41\x03R\townerName\x12:\n\x05owner\x18\x11 \x01(\x0b\x32\x17.core.mgmt.v1beta.OwnerB\x06\xe0\x41\x01\xe0\x41\x03H\x01R\x05owner\x88\x01\x01\x12\x1e\n\x06region\x18\x12 \x01(\tB\x06\xe0\x41\x02\xe0\x41\x05R\x06region\x12\x1f\n\x08hardware\x18\x13 \x01(\tB\x03\xe0\x41\x02R\x08hardware\x12 \n\x06readme\x18\x14 \x01(\tB\x03\xe0\x41\x01H\x02R\x06readme\x88\x01\x01\x12\'\n\nsource_url\x18\x15 \x01(\tB\x03\xe0\x41\x01H\x03R\tsourceUrl\x88\x01\x01\x12\x35\n\x11\x64ocumentation_url\x18\x16 \x01(\tB\x03\xe0\x41\x01H\x04R\x10\x64ocumentationUrl\x88\x01\x01\x12\"\n\x07license\x18\x17 \x01(\tB\x03\xe0\x41\x01H\x05R\x07license\x88\x01\x01\x12-\n\rprofile_image\x18\x1a \x01(\tB\x03\xe0\x41\x01H\x06R\x0cprofileImage\x88\x01\x01\x12\x44\n\npermission\x18\x1b \x01(\x0b\x32\x1f.model.model.v1alpha.PermissionB\x03\xe0\x41\x03R\npermission\x12?\n\x0cinput_schema\x18\x1c \x01(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x03R\x0binputSchema\x12\x41\n\routput_schema\x18\x1d \x01(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x03R\x0coutputSchema\x12\x17\n\x04tags\x18\x1e \x03(\tB\x03\xe0\x41\x03R\x04tags\x12\x1f\n\x08versions\x18\x1f \x03(\tB\x03\xe0\x41\x03R\x08versions\x12;\n\x05stats\x18  \x01(\x0b\x32 .model.model.v1alpha.Model.StatsB\x03\xe0\x41\x03R\x05stats\x1aw\n\x05Stats\x12)\n\x0enumber_of_runs\x18\x01 \x01(\x05\x42\x03\xe0\x41\x03R\x0cnumberOfRuns\x12\x43\n\rlast_run_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\x0blastRunTime\"W\n\nVisibility\x12\x1a\n\x16VISIBILITY_UNSPECIFIED\x10\x00\x12\x16\n\x12VISIBILITY_PRIVATE\x10\x01\x12\x15\n\x11VISIBILITY_PUBLIC\x10\x02:R\xea\x41O\n\x16\x61pi.instill.tech/Model\x12!users/{user.id}/models/{model.id}\x12\x12models/{model.uid}B\x0e\n\x0c_descriptionB\x08\n\x06_ownerB\t\n\x07_readmeB\r\n\x0b_source_urlB\x14\n\x12_documentation_urlB\n\n\x08_licenseB\x10\n\x0e_profile_imageJ\x04\x08\x08\x10\tJ\x04\x08\x10\x10\x11J\x04\x08\x18\x10\x19J\x04\x08\x19\x10\x1a\"\xbf\x03\n\x11ListModelsRequest\x12%\n\tpage_size\x18\x01 \x01(\x05\x42\x03\xe0\x41\x01H\x00R\x08pageSize\x88\x01\x01\x12\'\n\npage_token\x18\x02 \x01(\tB\x03\xe0\x41\x01H\x01R\tpageToken\x88\x01\x01\x12\x37\n\x04view\x18\x03 \x01(\x0e\x32\x19.model.model.v1alpha.ViewB\x03\xe0\x41\x01H\x02R\x04view\x88\x01\x01\x12+\n\x0cshow_deleted\x18\x04 \x01(\x08\x42\x03\xe0\x41\x01H\x03R\x0bshowDeleted\x88\x01\x01\x12 \n\x06\x66ilter\x18\x05 \x01(\tB\x03\xe0\x41\x01H\x04R\x06\x66ilter\x88\x01\x01\x12O\n\nvisibility\x18\x06 \x01(\x0e\x32%.model.model.v1alpha.Model.VisibilityB\x03\xe0\x41\x01H\x05R\nvisibility\x88\x01\x01\x12#\n\x08order_by\x18\x07 \x01(\tB\x03\xe0\x41\x01H\x06R\x07orderBy\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\x07\n\x05_viewB\x0f\n\r_show_deletedB\t\n\x07_filterB\r\n\x0b_visibilityB\x0b\n\t_order_by\"\x9e\x01\n\x12ListModelsResponse\x12\x37\n\x06models\x18\x01 \x03(\x0b\x32\x1a.model.model.v1alpha.ModelB\x03\xe0\x41\x03R\x06models\x12+\n\x0fnext_page_token\x18\x02 \x01(\tB\x03\xe0\x41\x03R\rnextPageToken\x12\"\n\ntotal_size\x18\x03 \x01(\x05\x42\x03\xe0\x41\x03R\ttotalSize\"y\n\x12LookUpModelRequest\x12!\n\tpermalink\x18\x01 \x01(\tB\x03\xe0\x41\x02R\tpermalink\x12\x37\n\x04view\x18\x02 \x01(\x0e\x32\x19.model.model.v1alpha.ViewB\x03\xe0\x41\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_view\"L\n\x13LookUpModelResponse\x12\x35\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelB\x03\xe0\x41\x03R\x05model\"\xf0\x03\n\x1aListNamespaceModelsRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12%\n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01H\x00R\x08pageSize\x88\x01\x01\x12\'\n\npage_token\x18\x03 \x01(\tB\x03\xe0\x41\x01H\x01R\tpageToken\x88\x01\x01\x12\x37\n\x04view\x18\x04 \x01(\x0e\x32\x19.model.model.v1alpha.ViewB\x03\xe0\x41\x01H\x02R\x04view\x88\x01\x01\x12+\n\x0cshow_deleted\x18\x05 \x01(\x08\x42\x03\xe0\x41\x01H\x03R\x0bshowDeleted\x88\x01\x01\x12 \n\x06\x66ilter\x18\x06 \x01(\tB\x03\xe0\x41\x01H\x04R\x06\x66ilter\x88\x01\x01\x12O\n\nvisibility\x18\x07 \x01(\x0e\x32%.model.model.v1alpha.Model.VisibilityB\x03\xe0\x41\x01H\x05R\nvisibility\x88\x01\x01\x12#\n\x08order_by\x18\x08 \x01(\tB\x03\xe0\x41\x01H\x06R\x07orderBy\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\x07\n\x05_viewB\x0f\n\r_show_deletedB\t\n\x07_filterB\r\n\x0b_visibilityB\x0b\n\t_order_by\"\xa7\x01\n\x1bListNamespaceModelsResponse\x12\x37\n\x06models\x18\x01 \x03(\x0b\x32\x1a.model.model.v1alpha.ModelB\x03\xe0\x41\x03R\x06models\x12+\n\x0fnext_page_token\x18\x02 \x01(\tB\x03\xe0\x41\x03R\rnextPageToken\x12\"\n\ntotal_size\x18\x03 \x01(\x05\x42\x03\xe0\x41\x03R\ttotalSize\"w\n\x1b\x43reateNamespaceModelRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\x30\n\x05model\x18\x02 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelR\x05model\"U\n\x1c\x43reateNamespaceModelResponse\x12\x35\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelB\x03\xe0\x41\x03R\x05model\"\xa4\x01\n\x18GetNamespaceModelRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\x1e\n\x08model_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x07modelId\x12\x37\n\x04view\x18\x03 \x01(\x0e\x32\x19.model.model.v1alpha.ViewB\x03\xe0\x41\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_view\"R\n\x19GetNamespaceModelResponse\x12\x35\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelB\x03\xe0\x41\x03R\x05model\"\xde\x01\n\x1bUpdateNamespaceModelRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\x1e\n\x08model_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x07modelId\x12\x35\n\x05model\x18\x03 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelB\x03\xe0\x41\x02R\x05model\x12@\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x03\xe0\x41\x02R\nupdateMask\"U\n\x1cUpdateNamespaceModelResponse\x12\x35\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelB\x03\xe0\x41\x03R\x05model\"e\n\x1b\x44\x65leteNamespaceModelRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\x1e\n\x08model_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x07modelId\"\x1e\n\x1c\x44\x65leteNamespaceModelResponse\"\x8c\x01\n\x1bRenameNamespaceModelRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\x1e\n\x08model_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x07modelId\x12%\n\x0cnew_model_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\nnewModelId\"U\n\x1cRenameNamespaceModelResponse\x12\x35\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelB\x03\xe0\x41\x03R\x05model\"\x83\x01\n\x1aWatchNamespaceModelRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\x1e\n\x08model_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x07modelId\x12\x1d\n\x07version\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x07version\"y\n\x1bWatchNamespaceModelResponse\x12\x35\n\x05state\x18\x01 \x01(\x0e\x32\x1a.model.model.v1alpha.StateB\x03\xe0\x41\x03R\x05state\x12\x1d\n\x07message\x18\x03 \x01(\tB\x03\xe0\x41\x03R\x07messageJ\x04\x08\x02\x10\x03\"j\n WatchNamespaceLatestModelRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\x1e\n\x08model_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x07modelId\"\x7f\n!WatchNamespaceLatestModelResponse\x12\x35\n\x05state\x18\x01 \x01(\x0e\x32\x1a.model.model.v1alpha.StateB\x03\xe0\x41\x03R\x05state\x12\x1d\n\x07message\x18\x03 \x01(\tB\x03\xe0\x41\x03R\x07messageJ\x04\x08\x02\x10\x03\"\xc7\x01\n!ListNamespaceModelVersionsRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\x1e\n\x08model_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x07modelId\x12%\n\tpage_size\x18\x03 \x01(\x05\x42\x03\xe0\x41\x01H\x00R\x08pageSize\x88\x01\x01\x12\x1c\n\x04page\x18\x04 \x01(\x05\x42\x03\xe0\x41\x01H\x01R\x04page\x88\x01\x01\x42\x0c\n\n_page_sizeB\x07\n\x05_page\"\xc7\x01\n\"ListNamespaceModelVersionsResponse\x12\x42\n\x08versions\x18\x01 \x03(\x0b\x32!.model.model.v1alpha.ModelVersionB\x03\xe0\x41\x03R\x08versions\x12\"\n\ntotal_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x03R\ttotalSize\x12 \n\tpage_size\x18\x03 \x01(\x05\x42\x03\xe0\x41\x03R\x08pageSize\x12\x17\n\x04page\x18\x04 \x01(\x05\x42\x03\xe0\x41\x03R\x04page\"\x8b\x01\n\"DeleteNamespaceModelVersionRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\x1e\n\x08model_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x07modelId\x12\x1d\n\x07version\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x07version\"%\n#DeleteNamespaceModelVersionResponse\"\xca\x01\n\x1cTriggerNamespaceModelRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\x1e\n\x08model_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x07modelId\x12\x1d\n\x07version\x18\x04 \x01(\tB\x03\xe0\x41\x02R\x07version\x12=\n\x0btask_inputs\x18\x05 \x03(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x02R\ntaskInputsJ\x04\x08\x03\x10\x04\"\x9a\x01\n\x1dTriggerNamespaceModelResponse\x12\x32\n\x04task\x18\x01 \x01(\x0e\x32\x19.common.task.v1alpha.TaskB\x03\xe0\x41\x03R\x04task\x12?\n\x0ctask_outputs\x18\x03 \x03(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x03R\x0btaskOutputsJ\x04\x08\x02\x10\x03\"\xcf\x01\n!TriggerAsyncNamespaceModelRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\x1e\n\x08model_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x07modelId\x12\x1d\n\x07version\x18\x04 \x01(\tB\x03\xe0\x41\x02R\x07version\x12=\n\x0btask_inputs\x18\x05 \x03(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x02R\ntaskInputsJ\x04\x08\x03\x10\x04\"f\n\"TriggerAsyncNamespaceModelResponse\x12@\n\toperation\x18\x01 \x01(\x0b\x32\x1d.google.longrunning.OperationB\x03\xe0\x41\x03R\toperation\"\xb1\x01\n\"TriggerNamespaceLatestModelRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\x1e\n\x08model_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x07modelId\x12=\n\x0btask_inputs\x18\x04 \x03(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x02R\ntaskInputsJ\x04\x08\x03\x10\x04\"\xa0\x01\n#TriggerNamespaceLatestModelResponse\x12\x32\n\x04task\x18\x01 \x01(\x0e\x32\x19.common.task.v1alpha.TaskB\x03\xe0\x41\x03R\x04task\x12?\n\x0ctask_outputs\x18\x03 \x03(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x03R\x0btaskOutputsJ\x04\x08\x02\x10\x03\"\xb6\x01\n\'TriggerAsyncNamespaceLatestModelRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\x1e\n\x08model_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x07modelId\x12=\n\x0btask_inputs\x18\x04 \x03(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x02R\ntaskInputsJ\x04\x08\x03\x10\x04\"l\n(TriggerAsyncNamespaceLatestModelResponse\x12@\n\toperation\x18\x01 \x01(\x0b\x32\x1d.google.longrunning.OperationB\x03\xe0\x41\x03R\toperation\"\xd8\x01\n,TriggerNamespaceModelBinaryFileUploadRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\x1e\n\x08model_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x07modelId\x12\x1d\n\x07version\x18\x04 \x01(\tB\x03\xe0\x41\x02R\x07version\x12;\n\ntask_input\x18\x05 \x03(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x02R\ttaskInputJ\x04\x08\x03\x10\x04\"\xb0\x01\n-TriggerNamespaceModelBinaryFileUploadResponse\x12\x32\n\x04task\x18\x01 \x01(\x0e\x32\x19.common.task.v1alpha.TaskB\x03\xe0\x41\x02R\x04task\x12?\n\x0ctask_outputs\x18\x04 \x03(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x03R\x0btaskOutputsJ\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04\"\xbf\x01\n2TriggerNamespaceLatestModelBinaryFileUploadRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\x1e\n\x08model_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x07modelId\x12;\n\ntask_input\x18\x04 \x03(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x02R\ttaskInputJ\x04\x08\x03\x10\x04\"\xb0\x01\n3TriggerNamespaceLatestModelBinaryFileUploadResponse\x12\x32\n\x04task\x18\x01 \x01(\x0e\x32\x19.common.task.v1alpha.TaskB\x03\xe0\x41\x02R\x04task\x12?\n\x0ctask_outputs\x18\x03 \x03(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x03R\x0btaskOutputsJ\x04\x08\x02\x10\x03\"\xb3\x01\n\'GetNamespaceLatestModelOperationRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\x1e\n\x08model_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x07modelId\x12\x37\n\x04view\x18\x03 \x01(\x0e\x32\x19.model.model.v1alpha.ViewB\x03\xe0\x41\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_view\"l\n(GetNamespaceLatestModelOperationResponse\x12@\n\toperation\x18\x01 \x01(\x0b\x32\x1d.google.longrunning.OperationB\x03\xe0\x41\x03R\toperation\"\xcc\x01\n!GetNamespaceModelOperationRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\x1e\n\x08model_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x07modelId\x12\x1d\n\x07version\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x07version\x12\x37\n\x04view\x18\x04 \x01(\x0e\x32\x19.model.model.v1alpha.ViewB\x03\xe0\x41\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_view\"a\n\"GetNamespaceModelOperationResponse\x12;\n\toperation\x18\x01 \x01(\x0b\x32\x1d.google.longrunning.OperationR\toperation\"\xa6\x01\n DeployNamespaceModelAdminRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\x1e\n\x08model_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x07modelId\x12\x1d\n\x07version\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x07version\x12\x1b\n\x06\x64igest\x18\x04 \x01(\tB\x03\xe0\x41\x01R\x06\x64igest\")\n!DeployNamespaceModelAdminResponseJ\x04\x08\x01\x10\x02\"\xa8\x01\n\"UndeployNamespaceModelAdminRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\x1e\n\x08model_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x07modelId\x12\x1d\n\x07version\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x07version\x12\x1b\n\x06\x64igest\x18\x04 \x01(\tB\x03\xe0\x41\x01R\x06\x64igest\"+\n#UndeployNamespaceModelAdminResponseJ\x04\x08\x01\x10\x02\"\x94\x01\n\x16\x43reateUserModelRequest\x12\x30\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelR\x05model\x12H\n\x06parent\x18\x02 \x01(\tB0\x92\x41\x0f\xca>\x0c\xfa\x02\tuser_name\xe0\x41\x02\xfa\x41\x18\x12\x16\x61pi.instill.tech/ModelR\x06parent\"P\n\x17\x43reateUserModelResponse\x12\x35\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelB\x03\xe0\x41\x03R\x05model\"\x8d\x04\n\x15ListUserModelsRequest\x12%\n\tpage_size\x18\x01 \x01(\x05\x42\x03\xe0\x41\x01H\x00R\x08pageSize\x88\x01\x01\x12\'\n\npage_token\x18\x02 \x01(\tB\x03\xe0\x41\x01H\x01R\tpageToken\x88\x01\x01\x12\x37\n\x04view\x18\x03 \x01(\x0e\x32\x19.model.model.v1alpha.ViewB\x03\xe0\x41\x01H\x02R\x04view\x88\x01\x01\x12H\n\x06parent\x18\x04 \x01(\tB0\x92\x41\x0f\xca>\x0c\xfa\x02\tuser_name\xe0\x41\x02\xfa\x41\x18\x12\x16\x61pi.instill.tech/ModelR\x06parent\x12+\n\x0cshow_deleted\x18\x05 \x01(\x08\x42\x03\xe0\x41\x01H\x03R\x0bshowDeleted\x88\x01\x01\x12 \n\x06\x66ilter\x18\x06 \x01(\tB\x03\xe0\x41\x01H\x04R\x06\x66ilter\x88\x01\x01\x12O\n\nvisibility\x18\x07 \x01(\x0e\x32%.model.model.v1alpha.Model.VisibilityB\x03\xe0\x41\x01H\x05R\nvisibility\x88\x01\x01\x12#\n\x08order_by\x18\x08 \x01(\tB\x03\xe0\x41\x01H\x06R\x07orderBy\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\x07\n\x05_viewB\x0f\n\r_show_deletedB\t\n\x07_filterB\r\n\x0b_visibilityB\x0b\n\t_order_by\"\xa2\x01\n\x16ListUserModelsResponse\x12\x37\n\x06models\x18\x01 \x03(\x0b\x32\x1a.model.model.v1alpha.ModelB\x03\xe0\x41\x03R\x06models\x12+\n\x0fnext_page_token\x18\x02 \x01(\tB\x03\xe0\x41\x03R\rnextPageToken\x12\"\n\ntotal_size\x18\x03 \x01(\x05\x42\x03\xe0\x41\x03R\ttotalSize\"\xa3\x01\n\x13GetUserModelRequest\x12J\n\x04name\x18\x01 \x01(\tB6\x92\x41\x15\xca>\x12\xfa\x02\x0fuser_model_name\xe0\x41\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12\x37\n\x04view\x18\x02 \x01(\x0e\x32\x19.model.model.v1alpha.ViewB\x03\xe0\x41\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_view\"M\n\x14GetUserModelResponse\x12\x35\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelB\x03\xe0\x41\x03R\x05model\"\x91\x01\n\x16UpdateUserModelRequest\x12\x35\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelB\x03\xe0\x41\x02R\x05model\x12@\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x03\xe0\x41\x02R\nupdateMask\"P\n\x17UpdateUserModelResponse\x12\x35\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelB\x03\xe0\x41\x03R\x05model\"d\n\x16\x44\x65leteUserModelRequest\x12J\n\x04name\x18\x01 \x01(\tB6\x92\x41\x15\xca>\x12\xfa\x02\x0fuser_model_name\xe0\x41\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\"\x19\n\x17\x44\x65leteUserModelResponse\"\x8b\x01\n\x16RenameUserModelRequest\x12J\n\x04name\x18\x01 \x01(\tB6\x92\x41\x15\xca>\x12\xfa\x02\x0fuser_model_name\xe0\x41\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12%\n\x0cnew_model_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\nnewModelId\"P\n\x17RenameUserModelResponse\x12\x35\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelB\x03\xe0\x41\x03R\x05model\"\x82\x01\n\x15WatchUserModelRequest\x12J\n\x04name\x18\x01 \x01(\tB6\x92\x41\x15\xca>\x12\xfa\x02\x0fuser_model_name\xe0\x41\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12\x1d\n\x07version\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x07version\"t\n\x16WatchUserModelResponse\x12\x35\n\x05state\x18\x01 \x01(\x0e\x32\x1a.model.model.v1alpha.StateB\x03\xe0\x41\x03R\x05state\x12\x1d\n\x07message\x18\x03 \x01(\tB\x03\xe0\x41\x03R\x07messageJ\x04\x08\x02\x10\x03\"i\n\x1bWatchUserLatestModelRequest\x12J\n\x04name\x18\x01 \x01(\tB6\x92\x41\x15\xca>\x12\xfa\x02\x0fuser_model_name\xe0\x41\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\"z\n\x1cWatchUserLatestModelResponse\x12\x35\n\x05state\x18\x01 \x01(\x0e\x32\x1a.model.model.v1alpha.StateB\x03\xe0\x41\x03R\x05state\x12\x1d\n\x07message\x18\x03 \x01(\tB\x03\xe0\x41\x03R\x07messageJ\x04\x08\x02\x10\x03\"\xc6\x01\n\x1cListUserModelVersionsRequest\x12%\n\tpage_size\x18\x01 \x01(\x05\x42\x03\xe0\x41\x01H\x00R\x08pageSize\x88\x01\x01\x12\x1c\n\x04page\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01H\x01R\x04page\x88\x01\x01\x12J\n\x04name\x18\x03 \x01(\tB6\x92\x41\x15\xca>\x12\xfa\x02\x0fuser_model_name\xe0\x41\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04nameB\x0c\n\n_page_sizeB\x07\n\x05_page\"\xc2\x01\n\x1dListUserModelVersionsResponse\x12\x42\n\x08versions\x18\x01 \x03(\x0b\x32!.model.model.v1alpha.ModelVersionB\x03\xe0\x41\x03R\x08versions\x12\"\n\ntotal_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x03R\ttotalSize\x12 \n\tpage_size\x18\x03 \x01(\x05\x42\x03\xe0\x41\x03R\x08pageSize\x12\x17\n\x04page\x18\x04 \x01(\x05\x42\x03\xe0\x41\x03R\x04page\"\x8a\x01\n\x1d\x44\x65leteUserModelVersionRequest\x12J\n\x04name\x18\x01 \x01(\tB6\x92\x41\x15\xca>\x12\xfa\x02\x0fuser_model_name\xe0\x41\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12\x1d\n\x07version\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x07version\" \n\x1e\x44\x65leteUserModelVersionResponse\"\xc9\x01\n\x17TriggerUserModelRequest\x12J\n\x04name\x18\x01 \x01(\tB6\x92\x41\x15\xca>\x12\xfa\x02\x0fuser_model_name\xe0\x41\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12\x1d\n\x07version\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x07version\x12=\n\x0btask_inputs\x18\x04 \x03(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x02R\ntaskInputsJ\x04\x08\x02\x10\x03\"\x95\x01\n\x18TriggerUserModelResponse\x12\x32\n\x04task\x18\x01 \x01(\x0e\x32\x19.common.task.v1alpha.TaskB\x03\xe0\x41\x03R\x04task\x12?\n\x0ctask_outputs\x18\x03 \x03(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x03R\x0btaskOutputsJ\x04\x08\x02\x10\x03\"\xce\x01\n\x1cTriggerAsyncUserModelRequest\x12J\n\x04name\x18\x01 \x01(\tB6\x92\x41\x15\xca>\x12\xfa\x02\x0fuser_model_name\xe0\x41\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12\x1d\n\x07version\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x07version\x12=\n\x0btask_inputs\x18\x04 \x03(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x02R\ntaskInputsJ\x04\x08\x02\x10\x03\"a\n\x1dTriggerAsyncUserModelResponse\x12@\n\toperation\x18\x01 \x01(\x0b\x32\x1d.google.longrunning.OperationB\x03\xe0\x41\x03R\toperation\"\xb0\x01\n\x1dTriggerUserLatestModelRequest\x12J\n\x04name\x18\x01 \x01(\tB6\x92\x41\x15\xca>\x12\xfa\x02\x0fuser_model_name\xe0\x41\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12=\n\x0btask_inputs\x18\x03 \x03(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x02R\ntaskInputsJ\x04\x08\x02\x10\x03\"\x9b\x01\n\x1eTriggerUserLatestModelResponse\x12\x32\n\x04task\x18\x01 \x01(\x0e\x32\x19.common.task.v1alpha.TaskB\x03\xe0\x41\x03R\x04task\x12?\n\x0ctask_outputs\x18\x03 \x03(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x03R\x0btaskOutputsJ\x04\x08\x02\x10\x03\"\xb5\x01\n\"TriggerAsyncUserLatestModelRequest\x12J\n\x04name\x18\x01 \x01(\tB6\x92\x41\x15\xca>\x12\xfa\x02\x0fuser_model_name\xe0\x41\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12=\n\x0btask_inputs\x18\x03 \x03(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x02R\ntaskInputsJ\x04\x08\x02\x10\x03\"g\n#TriggerAsyncUserLatestModelResponse\x12@\n\toperation\x18\x01 \x01(\x0b\x32\x1d.google.longrunning.OperationB\x03\xe0\x41\x03R\toperation\"\xd9\x01\n\'TriggerUserModelBinaryFileUploadRequest\x12J\n\x04name\x18\x01 \x01(\tB6\x92\x41\x15\xca>\x12\xfa\x02\x0fuser_model_name\xe0\x41\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12\x1d\n\x07version\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x07version\x12=\n\x0btask_inputs\x18\x04 \x03(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x02R\ntaskInputsJ\x04\x08\x02\x10\x03\"\xab\x01\n(TriggerUserModelBinaryFileUploadResponse\x12\x32\n\x04task\x18\x01 \x01(\x0e\x32\x19.common.task.v1alpha.TaskB\x03\xe0\x41\x02R\x04task\x12?\n\x0ctask_outputs\x18\x04 \x03(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x03R\x0btaskOutputsJ\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04\"\xa4\x01\n\x1e\x43reateOrganizationModelRequest\x12\x30\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelR\x05model\x12P\n\x06parent\x18\x02 \x01(\tB8\x92\x41\x17\xca>\x14\xfa\x02\x11organization_name\xe0\x41\x02\xfa\x41\x18\x12\x16\x61pi.instill.tech/ModelR\x06parent\"X\n\x1f\x43reateOrganizationModelResponse\x12\x35\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelB\x03\xe0\x41\x03R\x05model\"\x9d\x04\n\x1dListOrganizationModelsRequest\x12%\n\tpage_size\x18\x01 \x01(\x05\x42\x03\xe0\x41\x01H\x00R\x08pageSize\x88\x01\x01\x12\'\n\npage_token\x18\x02 \x01(\tB\x03\xe0\x41\x01H\x01R\tpageToken\x88\x01\x01\x12\x37\n\x04view\x18\x03 \x01(\x0e\x32\x19.model.model.v1alpha.ViewB\x03\xe0\x41\x01H\x02R\x04view\x88\x01\x01\x12P\n\x06parent\x18\x04 \x01(\tB8\x92\x41\x17\xca>\x14\xfa\x02\x11organization_name\xe0\x41\x02\xfa\x41\x18\x12\x16\x61pi.instill.tech/ModelR\x06parent\x12+\n\x0cshow_deleted\x18\x05 \x01(\x08\x42\x03\xe0\x41\x01H\x03R\x0bshowDeleted\x88\x01\x01\x12 \n\x06\x66ilter\x18\x06 \x01(\tB\x03\xe0\x41\x01H\x04R\x06\x66ilter\x88\x01\x01\x12O\n\nvisibility\x18\x07 \x01(\x0e\x32%.model.model.v1alpha.Model.VisibilityB\x03\xe0\x41\x01H\x05R\nvisibility\x88\x01\x01\x12#\n\x08order_by\x18\x08 \x01(\tB\x03\xe0\x41\x01H\x06R\x07orderBy\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\x07\n\x05_viewB\x0f\n\r_show_deletedB\t\n\x07_filterB\r\n\x0b_visibilityB\x0b\n\t_order_by\"\xaa\x01\n\x1eListOrganizationModelsResponse\x12\x37\n\x06models\x18\x01 \x03(\x0b\x32\x1a.model.model.v1alpha.ModelB\x03\xe0\x41\x03R\x06models\x12+\n\x0fnext_page_token\x18\x02 \x01(\tB\x03\xe0\x41\x03R\rnextPageToken\x12\"\n\ntotal_size\x18\x03 \x01(\x05\x42\x03\xe0\x41\x03R\ttotalSize\"\xb3\x01\n\x1bGetOrganizationModelRequest\x12R\n\x04name\x18\x01 \x01(\tB>\x92\x41\x1d\xca>\x1a\xfa\x02\x17organization_model_name\xe0\x41\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12\x37\n\x04view\x18\x02 \x01(\x0e\x32\x19.model.model.v1alpha.ViewB\x03\xe0\x41\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_view\"U\n\x1cGetOrganizationModelResponse\x12\x35\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelB\x03\xe0\x41\x03R\x05model\"\x99\x01\n\x1eUpdateOrganizationModelRequest\x12\x35\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelB\x03\xe0\x41\x02R\x05model\x12@\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x03\xe0\x41\x02R\nupdateMask\"X\n\x1fUpdateOrganizationModelResponse\x12\x35\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelB\x03\xe0\x41\x03R\x05model\"t\n\x1e\x44\x65leteOrganizationModelRequest\x12R\n\x04name\x18\x01 \x01(\tB>\x92\x41\x1d\xca>\x1a\xfa\x02\x17organization_model_name\xe0\x41\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\"!\n\x1f\x44\x65leteOrganizationModelResponse\"\x9b\x01\n\x1eRenameOrganizationModelRequest\x12R\n\x04name\x18\x01 \x01(\tB>\x92\x41\x1d\xca>\x1a\xfa\x02\x17organization_model_name\xe0\x41\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12%\n\x0cnew_model_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\nnewModelId\"X\n\x1fRenameOrganizationModelResponse\x12\x35\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelB\x03\xe0\x41\x03R\x05model\"\x92\x01\n\x1dWatchOrganizationModelRequest\x12R\n\x04name\x18\x01 \x01(\tB>\x92\x41\x1d\xca>\x1a\xfa\x02\x17organization_model_name\xe0\x41\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12\x1d\n\x07version\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x07version\"|\n\x1eWatchOrganizationModelResponse\x12\x35\n\x05state\x18\x01 \x01(\x0e\x32\x1a.model.model.v1alpha.StateB\x03\xe0\x41\x03R\x05state\x12\x1d\n\x07message\x18\x03 \x01(\tB\x03\xe0\x41\x03R\x07messageJ\x04\x08\x02\x10\x03\"y\n#WatchOrganizationLatestModelRequest\x12R\n\x04name\x18\x01 \x01(\tB>\x92\x41\x1d\xca>\x1a\xfa\x02\x17organization_model_name\xe0\x41\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\"\x82\x01\n$WatchOrganizationLatestModelResponse\x12\x35\n\x05state\x18\x01 \x01(\x0e\x32\x1a.model.model.v1alpha.StateB\x03\xe0\x41\x03R\x05state\x12\x1d\n\x07message\x18\x03 \x01(\tB\x03\xe0\x41\x03R\x07messageJ\x04\x08\x02\x10\x03\"\xd6\x01\n$ListOrganizationModelVersionsRequest\x12%\n\tpage_size\x18\x01 \x01(\x05\x42\x03\xe0\x41\x01H\x00R\x08pageSize\x88\x01\x01\x12\x1c\n\x04page\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01H\x01R\x04page\x88\x01\x01\x12R\n\x04name\x18\x03 \x01(\tB>\x92\x41\x1d\xca>\x1a\xfa\x02\x17organization_model_name\xe0\x41\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04nameB\x0c\n\n_page_sizeB\x07\n\x05_page\"\xca\x01\n%ListOrganizationModelVersionsResponse\x12\x42\n\x08versions\x18\x01 \x03(\x0b\x32!.model.model.v1alpha.ModelVersionB\x03\xe0\x41\x03R\x08versions\x12\"\n\ntotal_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x03R\ttotalSize\x12 \n\tpage_size\x18\x03 \x01(\x05\x42\x03\xe0\x41\x03R\x08pageSize\x12\x17\n\x04page\x18\x04 \x01(\x05\x42\x03\xe0\x41\x03R\x04page\"\x9a\x01\n%DeleteOrganizationModelVersionRequest\x12R\n\x04name\x18\x01 \x01(\tB>\x92\x41\x1d\xca>\x1a\xfa\x02\x17organization_model_name\xe0\x41\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12\x1d\n\x07version\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x07version\"(\n&DeleteOrganizationModelVersionResponse\"\xd9\x01\n\x1fTriggerOrganizationModelRequest\x12R\n\x04name\x18\x01 \x01(\tB>\x92\x41\x1d\xca>\x1a\xfa\x02\x17organization_model_name\xe0\x41\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12\x1d\n\x07version\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x07version\x12=\n\x0btask_inputs\x18\x04 \x03(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x02R\ntaskInputsJ\x04\x08\x02\x10\x03\"\x9d\x01\n TriggerOrganizationModelResponse\x12\x32\n\x04task\x18\x01 \x01(\x0e\x32\x19.common.task.v1alpha.TaskB\x03\xe0\x41\x03R\x04task\x12?\n\x0ctask_outputs\x18\x03 \x03(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x03R\x0btaskOutputsJ\x04\x08\x02\x10\x03\"\xde\x01\n$TriggerAsyncOrganizationModelRequest\x12R\n\x04name\x18\x01 \x01(\tB>\x92\x41\x1d\xca>\x1a\xfa\x02\x17organization_model_name\xe0\x41\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12\x1d\n\x07version\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x07version\x12=\n\x0btask_inputs\x18\x04 \x03(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x02R\ntaskInputsJ\x04\x08\x02\x10\x03\"i\n%TriggerAsyncOrganizationModelResponse\x12@\n\toperation\x18\x01 \x01(\x0b\x32\x1d.google.longrunning.OperationB\x03\xe0\x41\x03R\toperation\"\xc0\x01\n%TriggerOrganizationLatestModelRequest\x12R\n\x04name\x18\x01 \x01(\tB>\x92\x41\x1d\xca>\x1a\xfa\x02\x17organization_model_name\xe0\x41\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12=\n\x0btask_inputs\x18\x03 \x03(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x02R\ntaskInputsJ\x04\x08\x02\x10\x03\"\xa3\x01\n&TriggerOrganizationLatestModelResponse\x12\x32\n\x04task\x18\x01 \x01(\x0e\x32\x19.common.task.v1alpha.TaskB\x03\xe0\x41\x03R\x04task\x12?\n\x0ctask_outputs\x18\x03 \x03(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x03R\x0btaskOutputsJ\x04\x08\x02\x10\x03\"\xc5\x01\n*TriggerAsyncOrganizationLatestModelRequest\x12R\n\x04name\x18\x01 \x01(\tB>\x92\x41\x1d\xca>\x1a\xfa\x02\x17organization_model_name\xe0\x41\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12=\n\x0btask_inputs\x18\x03 \x03(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x02R\ntaskInputsJ\x04\x08\x02\x10\x03\"o\n+TriggerAsyncOrganizationLatestModelResponse\x12@\n\toperation\x18\x01 \x01(\x0b\x32\x1d.google.longrunning.OperationB\x03\xe0\x41\x03R\toperation\"\xe9\x01\n/TriggerOrganizationModelBinaryFileUploadRequest\x12R\n\x04name\x18\x01 \x01(\tB>\x92\x41\x1d\xca>\x1a\xfa\x02\x17organization_model_name\xe0\x41\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12\x1d\n\x07version\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x07version\x12=\n\x0btask_inputs\x18\x04 \x03(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x02R\ntaskInputsJ\x04\x08\x02\x10\x03\"\xa8\x01\n0TriggerOrganizationModelBinaryFileUploadResponse\x12\x32\n\x04task\x18\x01 \x01(\x0e\x32\x19.common.task.v1alpha.TaskB\x03\xe0\x41\x02R\x04task\x12:\n\x0ctask_outputs\x18\x04 \x03(\x0b\x32\x17.google.protobuf.StructR\x0btaskOutputsJ\x04\x08\x02\x10\x03\"\x86\x01\n\x18GetModelOperationRequest\x12&\n\x0coperation_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0boperationId\x12\x39\n\x04view\x18\x02 \x01(\x0e\x32\x19.model.model.v1alpha.ViewB\x05\x18\x01\xe0\x41\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_view\"]\n\x19GetModelOperationResponse\x12@\n\toperation\x18\x01 \x01(\x0b\x32\x1d.google.longrunning.OperationB\x03\xe0\x41\x03R\toperation\"\xba\x01\n\x0fLatestOperation\x12K\n\x07request\x18\x03 \x01(\x0b\x32\x31.model.model.v1alpha.TriggerNamespaceModelRequestR\x07request\x12N\n\x08response\x18\x04 \x01(\x0b\x32\x32.model.model.v1alpha.TriggerNamespaceModelResponseR\x08responseJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03\"\xb2\x01\n\"GetUserLatestModelOperationRequest\x12J\n\x04name\x18\x01 \x01(\tB6\x92\x41\x15\xca>\x12\xfa\x02\x0fuser_model_name\xe0\x41\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12\x37\n\x04view\x18\x02 \x01(\x0e\x32\x19.model.model.v1alpha.ViewB\x03\xe0\x41\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_view\"g\n#GetUserLatestModelOperationResponse\x12@\n\toperation\x18\x01 \x01(\x0b\x32\x1d.google.longrunning.OperationB\x03\xe0\x41\x03R\toperation\"\xc2\x01\n*GetOrganizationLatestModelOperationRequest\x12R\n\x04name\x18\x01 \x01(\tB>\x92\x41\x1d\xca>\x1a\xfa\x02\x17organization_model_name\xe0\x41\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12\x37\n\x04view\x18\x02 \x01(\x0e\x32\x19.model.model.v1alpha.ViewB\x03\xe0\x41\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_view\"o\n+GetOrganizationLatestModelOperationResponse\x12@\n\toperation\x18\x01 \x01(\x0b\x32\x1d.google.longrunning.OperationB\x03\xe0\x41\x03R\toperation\"\x1d\n\x1bListAvailableRegionsRequest\"Z\n\x1cListAvailableRegionsResponse\x12:\n\x07regions\x18\x01 \x03(\x0b\x32\x1b.model.model.v1alpha.RegionB\x03\xe0\x41\x03R\x07regions\"\xb2\x02\n\x16ListModelsAdminRequest\x12%\n\tpage_size\x18\x01 \x01(\x05\x42\x03\xe0\x41\x01H\x00R\x08pageSize\x88\x01\x01\x12\'\n\npage_token\x18\x02 \x01(\tB\x03\xe0\x41\x01H\x01R\tpageToken\x88\x01\x01\x12\x37\n\x04view\x18\x03 \x01(\x0e\x32\x19.model.model.v1alpha.ViewB\x03\xe0\x41\x01H\x02R\x04view\x88\x01\x01\x12+\n\x0cshow_deleted\x18\x04 \x01(\x08\x42\x03\xe0\x41\x01H\x03R\x0bshowDeleted\x88\x01\x01\x12 \n\x06\x66ilter\x18\x05 \x01(\tB\x03\xe0\x41\x01H\x04R\x06\x66ilter\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\x07\n\x05_viewB\x0f\n\r_show_deletedB\t\n\x07_filter\"\x94\x01\n\x17ListModelsAdminResponse\x12\x32\n\x06models\x18\x01 \x03(\x0b\x32\x1a.model.model.v1alpha.ModelR\x06models\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"~\n\x17LookUpModelAdminRequest\x12!\n\tpermalink\x18\x01 \x01(\tB\x03\xe0\x41\x02R\tpermalink\x12\x37\n\x04view\x18\x02 \x01(\x0e\x32\x19.model.model.v1alpha.ViewB\x03\xe0\x41\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_view\"L\n\x18LookUpModelAdminResponse\x12\x30\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelR\x05model\"\xab\x01\n\x1b\x44\x65ployUserModelAdminRequest\x12J\n\x04name\x18\x02 \x01(\tB6\x92\x41\x15\xca>\x12\xfa\x02\x0fuser_model_name\xe0\x41\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12\x1d\n\x07version\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x07version\x12\x1b\n\x06\x64igest\x18\x04 \x01(\tB\x03\xe0\x41\x01R\x06\x64igestJ\x04\x08\x01\x10\x02\"$\n\x1c\x44\x65ployUserModelAdminResponseJ\x04\x08\x01\x10\x02\"\xbb\x01\n#DeployOrganizationModelAdminRequest\x12R\n\x04name\x18\x02 \x01(\tB>\x92\x41\x1d\xca>\x1a\xfa\x02\x17organization_model_name\xe0\x41\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12\x1d\n\x07version\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x07version\x12\x1b\n\x06\x64igest\x18\x04 \x01(\tB\x03\xe0\x41\x01R\x06\x64igestJ\x04\x08\x01\x10\x02\"&\n$DeployOrganizationModelAdminResponse\"\xad\x01\n\x1dUndeployUserModelAdminRequest\x12J\n\x04name\x18\x02 \x01(\tB6\x92\x41\x15\xca>\x12\xfa\x02\x0fuser_model_name\xe0\x41\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12\x1d\n\x07version\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x07version\x12\x1b\n\x06\x64igest\x18\x04 \x01(\tB\x03\xe0\x41\x01R\x06\x64igestJ\x04\x08\x01\x10\x02\"&\n\x1eUndeployUserModelAdminResponseJ\x04\x08\x01\x10\x02\"\xbd\x01\n%UndeployOrganizationModelAdminRequest\x12R\n\x04name\x18\x02 \x01(\tB>\x92\x41\x1d\xca>\x1a\xfa\x02\x17organization_model_name\xe0\x41\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12\x1d\n\x07version\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x07version\x12\x1b\n\x06\x64igest\x18\x04 \x01(\tB\x03\xe0\x41\x01R\x06\x64igestJ\x04\x08\x01\x10\x02\"(\n&UndeployOrganizationModelAdminResponse\"\xd4\x06\n\x08ModelRun\x12\x15\n\x03uid\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x03uid\x12 \n\tmodel_uid\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x08modelUid\x12:\n\x06status\x18\x03 \x01(\x0e\x32\x1d.common.run.v1alpha.RunStatusB\x03\xe0\x41\x03R\x06status\x12:\n\x06source\x18\x04 \x01(\x0e\x32\x1d.common.run.v1alpha.RunSourceB\x03\xe0\x41\x03R\x06source\x12\x32\n\x0etotal_duration\x18\x05 \x01(\x05\x42\x06\xe0\x41\x03\xe0\x41\x01H\x00R\rtotalDuration\x88\x01\x01\x12\x42\n\x08\x65nd_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xe0\x41\x03\xe0\x41\x01H\x01R\x07\x65ndTime\x88\x01\x01\x12(\n\trunner_id\x18\x07 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x01H\x02R\x08runnerId\x88\x01\x01\x12\x30\n\rcredit_amount\x18\x08 \x01(\x02\x42\x06\xe0\x41\x03\xe0\x41\x01H\x03R\x0c\x63reditAmount\x88\x01\x01\x12!\n\x05\x65rror\x18\t \x01(\tB\x06\xe0\x41\x03\xe0\x41\x01H\x04R\x05\x65rror\x88\x01\x01\x12@\n\x0b\x63reate_time\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12@\n\x0bupdate_time\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\nupdateTime\x12\x1d\n\x07version\x18\x0c \x01(\tB\x03\xe0\x41\x03R\x07version\x12=\n\x0btask_inputs\x18\r \x03(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x03R\ntaskInputs\x12?\n\x0ctask_outputs\x18\x0e \x03(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x03R\x0btaskOutputs\x12&\n\x08model_id\x18\x0f \x01(\tB\x06\xe0\x41\x03\xe0\x41\x01H\x05R\x07modelId\x88\x01\x01\x42\x11\n\x0f_total_durationB\x0b\n\t_end_timeB\x0c\n\n_runner_idB\x10\n\x0e_credit_amountB\x08\n\x06_errorB\x0b\n\t_model_id\"\x9f\x02\n\x14ListModelRunsRequest\x12%\n\tpage_size\x18\x01 \x01(\x05\x42\x03\xe0\x41\x01H\x00R\x08pageSize\x88\x01\x01\x12\x1c\n\x04page\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01H\x01R\x04page\x88\x01\x01\x12#\n\x08order_by\x18\x04 \x01(\tB\x03\xe0\x41\x01H\x02R\x07orderBy\x88\x01\x01\x12&\n\x0cnamespace_id\x18\x05 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\x1e\n\x08model_id\x18\x06 \x01(\tB\x03\xe0\x41\x02R\x07modelId\x12 \n\x06\x66ilter\x18\x07 \x01(\tB\x03\xe0\x41\x01H\x03R\x06\x66ilter\x88\x01\x01\x42\x0c\n\n_page_sizeB\x07\n\x05_pageB\x0b\n\t_order_byB\t\n\x07_filterJ\x04\x08\x03\x10\x04\"\xdd\x02\n!ListModelRunsByCreditOwnerRequest\x12%\n\tpage_size\x18\x01 \x01(\x05\x42\x03\xe0\x41\x01H\x00R\x08pageSize\x88\x01\x01\x12\x1c\n\x04page\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01H\x01R\x04page\x88\x01\x01\x12#\n\x08order_by\x18\x03 \x01(\tB\x03\xe0\x41\x01H\x02R\x07orderBy\x88\x01\x01\x12 \n\x06\x66ilter\x18\x04 \x01(\tB\x03\xe0\x41\x01H\x03R\x06\x66ilter\x88\x01\x01\x12\x35\n\x05start\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x04R\x05start\x88\x01\x01\x12\x33\n\x04stop\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x05R\x04stop\x88\x01\x01\x42\x0c\n\n_page_sizeB\x07\n\x05_pageB\x0b\n\t_order_byB\t\n\x07_filterB\x08\n\x06_startB\x07\n\x05_stop\"\xae\x01\n\x15ListModelRunsResponse\x12\x36\n\x04runs\x18\x01 \x03(\x0b\x32\x1d.model.model.v1alpha.ModelRunB\x03\xe0\x41\x03R\x04runs\x12\"\n\ntotal_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x03R\ttotalSize\x12 \n\tpage_size\x18\x03 \x01(\x05\x42\x03\xe0\x41\x03R\x08pageSize\x12\x17\n\x04page\x18\x04 \x01(\x05\x42\x03\xe0\x41\x03R\x04page\"\xbb\x01\n\"ListModelRunsByCreditOwnerResponse\x12\x36\n\x04runs\x18\x01 \x03(\x0b\x32\x1d.model.model.v1alpha.ModelRunB\x03\xe0\x41\x03R\x04runs\x12\"\n\ntotal_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x03R\ttotalSize\x12 \n\tpage_size\x18\x03 \x01(\x05\x42\x03\xe0\x41\x03R\x08pageSize\x12\x17\n\x04page\x18\x04 \x01(\x05\x42\x03\xe0\x41\x03R\x04page*\xac\x01\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x11\n\rSTATE_OFFLINE\x10\x01\x12\x10\n\x0cSTATE_ACTIVE\x10\x03\x12\x0e\n\nSTATE_IDLE\x10\x04\x12\x0f\n\x0bSTATE_ERROR\x10\x05\x12\x12\n\x0eSTATE_STARTING\x10\x06\x12\x14\n\x10STATE_SCALING_UP\x10\x07\x12\x16\n\x12STATE_SCALING_DOWN\x10\x08\"\x04\x08\x02\x10\x02\x42\xd7\x01\n\x17\x63om.model.model.v1alphaB\nModelProtoP\x01ZBgithub.com/instill-ai/protogen-go/model/model/v1alpha;modelv1alpha\xa2\x02\x03MMX\xaa\x02\x13Model.Model.V1alpha\xca\x02\x13Model\\Model\\V1alpha\xe2\x02\x1fModel\\Model\\V1alpha\\GPBMetadata\xea\x02\x15Model::Model::V1alphab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'model.model.v1alpha.model_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.model.model.v1alphaB\nModelProtoP\001ZBgithub.com/instill-ai/protogen-go/model/model/v1alpha;modelv1alpha\242\002\003MMX\252\002\023Model.Model.V1alpha\312\002\023Model\\Model\\V1alpha\342\002\037Model\\Model\\V1alpha\\GPBMetadata\352\002\025Model::Model::V1alpha'
  _LIVENESSREQUEST.fields_by_name['health_check_request']._options = None
  _LIVENESSREQUEST.fields_by_name['health_check_request']._serialized_options = b'\340A\001'
  _READINESSREQUEST.fields_by_name['health_check_request']._options = None
  _READINESSREQUEST.fields_by_name['health_check_request']._serialized_options = b'\340A\001'
  _MODELVERSION.fields_by_name['name']._options = None
  _MODELVERSION.fields_by_name['name']._serialized_options = b'\340A\005'
  _MODELVERSION.fields_by_name['version']._options = None
  _MODELVERSION.fields_by_name['version']._serialized_options = b'\340A\005'
  _MODELVERSION.fields_by_name['digest']._options = None
  _MODELVERSION.fields_by_name['digest']._serialized_options = b'\340A\001'
  _MODELVERSION.fields_by_name['state']._options = None
  _MODELVERSION.fields_by_name['state']._serialized_options = b'\340A\003'
  _MODELVERSION.fields_by_name['update_time']._options = None
  _MODELVERSION.fields_by_name['update_time']._serialized_options = b'\340A\003\340A\001'
  _MODEL_STATS.fields_by_name['number_of_runs']._options = None
  _MODEL_STATS.fields_by_name['number_of_runs']._serialized_options = b'\340A\003'
  _MODEL_STATS.fields_by_name['last_run_time']._options = None
  _MODEL_STATS.fields_by_name['last_run_time']._serialized_options = b'\340A\003'
  _MODEL.fields_by_name['name']._options = None
  _MODEL.fields_by_name['name']._serialized_options = b'\222A\020\312>\r\372\002\nmodel_name\340A\003'
  _MODEL.fields_by_name['uid']._options = None
  _MODEL.fields_by_name['uid']._serialized_options = b'\340A\003'
  _MODEL.fields_by_name['id']._options = None
  _MODEL.fields_by_name['id']._serialized_options = b'\340A\002\340A\005'
  _MODEL.fields_by_name['description']._options = None
  _MODEL.fields_by_name['description']._serialized_options = b'\340A\001'
  _MODEL.fields_by_name['model_definition']._options = None
  _MODEL.fields_by_name['model_definition']._serialized_options = b'\340A\002\340A\005\372A\"\n api.instill.tech/ModelDefinition'
  _MODEL.fields_by_name['configuration']._options = None
  _MODEL.fields_by_name['configuration']._serialized_options = b'\340A\002\340A\005'
  _MODEL.fields_by_name['task']._options = None
  _MODEL.fields_by_name['task']._serialized_options = b'\340A\002\340A\005'
  _MODEL.fields_by_name['visibility']._options = None
  _MODEL.fields_by_name['visibility']._serialized_options = b'\340A\002'
  _MODEL.fields_by_name['create_time']._options = None
  _MODEL.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _MODEL.fields_by_name['update_time']._options = None
  _MODEL.fields_by_name['update_time']._serialized_options = b'\340A\003'
  _MODEL.fields_by_name['delete_time']._options = None
  _MODEL.fields_by_name['delete_time']._serialized_options = b'\340A\003'
  _MODEL.fields_by_name['owner_name']._options = None
  _MODEL.fields_by_name['owner_name']._serialized_options = b'\340A\003'
  _MODEL.fields_by_name['owner']._options = None
  _MODEL.fields_by_name['owner']._serialized_options = b'\340A\001\340A\003'
  _MODEL.fields_by_name['region']._options = None
  _MODEL.fields_by_name['region']._serialized_options = b'\340A\002\340A\005'
  _MODEL.fields_by_name['hardware']._options = None
  _MODEL.fields_by_name['hardware']._serialized_options = b'\340A\002'
  _MODEL.fields_by_name['readme']._options = None
  _MODEL.fields_by_name['readme']._serialized_options = b'\340A\001'
  _MODEL.fields_by_name['source_url']._options = None
  _MODEL.fields_by_name['source_url']._serialized_options = b'\340A\001'
  _MODEL.fields_by_name['documentation_url']._options = None
  _MODEL.fields_by_name['documentation_url']._serialized_options = b'\340A\001'
  _MODEL.fields_by_name['license']._options = None
  _MODEL.fields_by_name['license']._serialized_options = b'\340A\001'
  _MODEL.fields_by_name['profile_image']._options = None
  _MODEL.fields_by_name['profile_image']._serialized_options = b'\340A\001'
  _MODEL.fields_by_name['permission']._options = None
  _MODEL.fields_by_name['permission']._serialized_options = b'\340A\003'
  _MODEL.fields_by_name['input_schema']._options = None
  _MODEL.fields_by_name['input_schema']._serialized_options = b'\340A\003'
  _MODEL.fields_by_name['output_schema']._options = None
  _MODEL.fields_by_name['output_schema']._serialized_options = b'\340A\003'
  _MODEL.fields_by_name['tags']._options = None
  _MODEL.fields_by_name['tags']._serialized_options = b'\340A\003'
  _MODEL.fields_by_name['versions']._options = None
  _MODEL.fields_by_name['versions']._serialized_options = b'\340A\003'
  _MODEL.fields_by_name['stats']._options = None
  _MODEL.fields_by_name['stats']._serialized_options = b'\340A\003'
  _MODEL._options = None
  _MODEL._serialized_options = b'\352AO\n\026api.instill.tech/Model\022!users/{user.id}/models/{model.id}\022\022models/{model.uid}'
  _LISTMODELSREQUEST.fields_by_name['page_size']._options = None
  _LISTMODELSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTMODELSREQUEST.fields_by_name['page_token']._options = None
  _LISTMODELSREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTMODELSREQUEST.fields_by_name['view']._options = None
  _LISTMODELSREQUEST.fields_by_name['view']._serialized_options = b'\340A\001'
  _LISTMODELSREQUEST.fields_by_name['show_deleted']._options = None
  _LISTMODELSREQUEST.fields_by_name['show_deleted']._serialized_options = b'\340A\001'
  _LISTMODELSREQUEST.fields_by_name['filter']._options = None
  _LISTMODELSREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTMODELSREQUEST.fields_by_name['visibility']._options = None
  _LISTMODELSREQUEST.fields_by_name['visibility']._serialized_options = b'\340A\001'
  _LISTMODELSREQUEST.fields_by_name['order_by']._options = None
  _LISTMODELSREQUEST.fields_by_name['order_by']._serialized_options = b'\340A\001'
  _LISTMODELSRESPONSE.fields_by_name['models']._options = None
  _LISTMODELSRESPONSE.fields_by_name['models']._serialized_options = b'\340A\003'
  _LISTMODELSRESPONSE.fields_by_name['next_page_token']._options = None
  _LISTMODELSRESPONSE.fields_by_name['next_page_token']._serialized_options = b'\340A\003'
  _LISTMODELSRESPONSE.fields_by_name['total_size']._options = None
  _LISTMODELSRESPONSE.fields_by_name['total_size']._serialized_options = b'\340A\003'
  _LOOKUPMODELREQUEST.fields_by_name['permalink']._options = None
  _LOOKUPMODELREQUEST.fields_by_name['permalink']._serialized_options = b'\340A\002'
  _LOOKUPMODELREQUEST.fields_by_name['view']._options = None
  _LOOKUPMODELREQUEST.fields_by_name['view']._serialized_options = b'\340A\001'
  _LOOKUPMODELRESPONSE.fields_by_name['model']._options = None
  _LOOKUPMODELRESPONSE.fields_by_name['model']._serialized_options = b'\340A\003'
  _LISTNAMESPACEMODELSREQUEST.fields_by_name['namespace_id']._options = None
  _LISTNAMESPACEMODELSREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _LISTNAMESPACEMODELSREQUEST.fields_by_name['page_size']._options = None
  _LISTNAMESPACEMODELSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTNAMESPACEMODELSREQUEST.fields_by_name['page_token']._options = None
  _LISTNAMESPACEMODELSREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTNAMESPACEMODELSREQUEST.fields_by_name['view']._options = None
  _LISTNAMESPACEMODELSREQUEST.fields_by_name['view']._serialized_options = b'\340A\001'
  _LISTNAMESPACEMODELSREQUEST.fields_by_name['show_deleted']._options = None
  _LISTNAMESPACEMODELSREQUEST.fields_by_name['show_deleted']._serialized_options = b'\340A\001'
  _LISTNAMESPACEMODELSREQUEST.fields_by_name['filter']._options = None
  _LISTNAMESPACEMODELSREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTNAMESPACEMODELSREQUEST.fields_by_name['visibility']._options = None
  _LISTNAMESPACEMODELSREQUEST.fields_by_name['visibility']._serialized_options = b'\340A\001'
  _LISTNAMESPACEMODELSREQUEST.fields_by_name['order_by']._options = None
  _LISTNAMESPACEMODELSREQUEST.fields_by_name['order_by']._serialized_options = b'\340A\001'
  _LISTNAMESPACEMODELSRESPONSE.fields_by_name['models']._options = None
  _LISTNAMESPACEMODELSRESPONSE.fields_by_name['models']._serialized_options = b'\340A\003'
  _LISTNAMESPACEMODELSRESPONSE.fields_by_name['next_page_token']._options = None
  _LISTNAMESPACEMODELSRESPONSE.fields_by_name['next_page_token']._serialized_options = b'\340A\003'
  _LISTNAMESPACEMODELSRESPONSE.fields_by_name['total_size']._options = None
  _LISTNAMESPACEMODELSRESPONSE.fields_by_name['total_size']._serialized_options = b'\340A\003'
  _CREATENAMESPACEMODELREQUEST.fields_by_name['namespace_id']._options = None
  _CREATENAMESPACEMODELREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _CREATENAMESPACEMODELRESPONSE.fields_by_name['model']._options = None
  _CREATENAMESPACEMODELRESPONSE.fields_by_name['model']._serialized_options = b'\340A\003'
  _GETNAMESPACEMODELREQUEST.fields_by_name['namespace_id']._options = None
  _GETNAMESPACEMODELREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _GETNAMESPACEMODELREQUEST.fields_by_name['model_id']._options = None
  _GETNAMESPACEMODELREQUEST.fields_by_name['model_id']._serialized_options = b'\340A\002'
  _GETNAMESPACEMODELREQUEST.fields_by_name['view']._options = None
  _GETNAMESPACEMODELREQUEST.fields_by_name['view']._serialized_options = b'\340A\001'
  _GETNAMESPACEMODELRESPONSE.fields_by_name['model']._options = None
  _GETNAMESPACEMODELRESPONSE.fields_by_name['model']._serialized_options = b'\340A\003'
  _UPDATENAMESPACEMODELREQUEST.fields_by_name['namespace_id']._options = None
  _UPDATENAMESPACEMODELREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _UPDATENAMESPACEMODELREQUEST.fields_by_name['model_id']._options = None
  _UPDATENAMESPACEMODELREQUEST.fields_by_name['model_id']._serialized_options = b'\340A\002'
  _UPDATENAMESPACEMODELREQUEST.fields_by_name['model']._options = None
  _UPDATENAMESPACEMODELREQUEST.fields_by_name['model']._serialized_options = b'\340A\002'
  _UPDATENAMESPACEMODELREQUEST.fields_by_name['update_mask']._options = None
  _UPDATENAMESPACEMODELREQUEST.fields_by_name['update_mask']._serialized_options = b'\340A\002'
  _UPDATENAMESPACEMODELRESPONSE.fields_by_name['model']._options = None
  _UPDATENAMESPACEMODELRESPONSE.fields_by_name['model']._serialized_options = b'\340A\003'
  _DELETENAMESPACEMODELREQUEST.fields_by_name['namespace_id']._options = None
  _DELETENAMESPACEMODELREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _DELETENAMESPACEMODELREQUEST.fields_by_name['model_id']._options = None
  _DELETENAMESPACEMODELREQUEST.fields_by_name['model_id']._serialized_options = b'\340A\002'
  _RENAMENAMESPACEMODELREQUEST.fields_by_name['namespace_id']._options = None
  _RENAMENAMESPACEMODELREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _RENAMENAMESPACEMODELREQUEST.fields_by_name['model_id']._options = None
  _RENAMENAMESPACEMODELREQUEST.fields_by_name['model_id']._serialized_options = b'\340A\002'
  _RENAMENAMESPACEMODELREQUEST.fields_by_name['new_model_id']._options = None
  _RENAMENAMESPACEMODELREQUEST.fields_by_name['new_model_id']._serialized_options = b'\340A\002'
  _RENAMENAMESPACEMODELRESPONSE.fields_by_name['model']._options = None
  _RENAMENAMESPACEMODELRESPONSE.fields_by_name['model']._serialized_options = b'\340A\003'
  _WATCHNAMESPACEMODELREQUEST.fields_by_name['namespace_id']._options = None
  _WATCHNAMESPACEMODELREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _WATCHNAMESPACEMODELREQUEST.fields_by_name['model_id']._options = None
  _WATCHNAMESPACEMODELREQUEST.fields_by_name['model_id']._serialized_options = b'\340A\002'
  _WATCHNAMESPACEMODELREQUEST.fields_by_name['version']._options = None
  _WATCHNAMESPACEMODELREQUEST.fields_by_name['version']._serialized_options = b'\340A\002'
  _WATCHNAMESPACEMODELRESPONSE.fields_by_name['state']._options = None
  _WATCHNAMESPACEMODELRESPONSE.fields_by_name['state']._serialized_options = b'\340A\003'
  _WATCHNAMESPACEMODELRESPONSE.fields_by_name['message']._options = None
  _WATCHNAMESPACEMODELRESPONSE.fields_by_name['message']._serialized_options = b'\340A\003'
  _WATCHNAMESPACELATESTMODELREQUEST.fields_by_name['namespace_id']._options = None
  _WATCHNAMESPACELATESTMODELREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _WATCHNAMESPACELATESTMODELREQUEST.fields_by_name['model_id']._options = None
  _WATCHNAMESPACELATESTMODELREQUEST.fields_by_name['model_id']._serialized_options = b'\340A\002'
  _WATCHNAMESPACELATESTMODELRESPONSE.fields_by_name['state']._options = None
  _WATCHNAMESPACELATESTMODELRESPONSE.fields_by_name['state']._serialized_options = b'\340A\003'
  _WATCHNAMESPACELATESTMODELRESPONSE.fields_by_name['message']._options = None
  _WATCHNAMESPACELATESTMODELRESPONSE.fields_by_name['message']._serialized_options = b'\340A\003'
  _LISTNAMESPACEMODELVERSIONSREQUEST.fields_by_name['namespace_id']._options = None
  _LISTNAMESPACEMODELVERSIONSREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _LISTNAMESPACEMODELVERSIONSREQUEST.fields_by_name['model_id']._options = None
  _LISTNAMESPACEMODELVERSIONSREQUEST.fields_by_name['model_id']._serialized_options = b'\340A\002'
  _LISTNAMESPACEMODELVERSIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTNAMESPACEMODELVERSIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTNAMESPACEMODELVERSIONSREQUEST.fields_by_name['page']._options = None
  _LISTNAMESPACEMODELVERSIONSREQUEST.fields_by_name['page']._serialized_options = b'\340A\001'
  _LISTNAMESPACEMODELVERSIONSRESPONSE.fields_by_name['versions']._options = None
  _LISTNAMESPACEMODELVERSIONSRESPONSE.fields_by_name['versions']._serialized_options = b'\340A\003'
  _LISTNAMESPACEMODELVERSIONSRESPONSE.fields_by_name['total_size']._options = None
  _LISTNAMESPACEMODELVERSIONSRESPONSE.fields_by_name['total_size']._serialized_options = b'\340A\003'
  _LISTNAMESPACEMODELVERSIONSRESPONSE.fields_by_name['page_size']._options = None
  _LISTNAMESPACEMODELVERSIONSRESPONSE.fields_by_name['page_size']._serialized_options = b'\340A\003'
  _LISTNAMESPACEMODELVERSIONSRESPONSE.fields_by_name['page']._options = None
  _LISTNAMESPACEMODELVERSIONSRESPONSE.fields_by_name['page']._serialized_options = b'\340A\003'
  _DELETENAMESPACEMODELVERSIONREQUEST.fields_by_name['namespace_id']._options = None
  _DELETENAMESPACEMODELVERSIONREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _DELETENAMESPACEMODELVERSIONREQUEST.fields_by_name['model_id']._options = None
  _DELETENAMESPACEMODELVERSIONREQUEST.fields_by_name['model_id']._serialized_options = b'\340A\002'
  _DELETENAMESPACEMODELVERSIONREQUEST.fields_by_name['version']._options = None
  _DELETENAMESPACEMODELVERSIONREQUEST.fields_by_name['version']._serialized_options = b'\340A\002'
  _TRIGGERNAMESPACEMODELREQUEST.fields_by_name['namespace_id']._options = None
  _TRIGGERNAMESPACEMODELREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _TRIGGERNAMESPACEMODELREQUEST.fields_by_name['model_id']._options = None
  _TRIGGERNAMESPACEMODELREQUEST.fields_by_name['model_id']._serialized_options = b'\340A\002'
  _TRIGGERNAMESPACEMODELREQUEST.fields_by_name['version']._options = None
  _TRIGGERNAMESPACEMODELREQUEST.fields_by_name['version']._serialized_options = b'\340A\002'
  _TRIGGERNAMESPACEMODELREQUEST.fields_by_name['task_inputs']._options = None
  _TRIGGERNAMESPACEMODELREQUEST.fields_by_name['task_inputs']._serialized_options = b'\340A\002'
  _TRIGGERNAMESPACEMODELRESPONSE.fields_by_name['task']._options = None
  _TRIGGERNAMESPACEMODELRESPONSE.fields_by_name['task']._serialized_options = b'\340A\003'
  _TRIGGERNAMESPACEMODELRESPONSE.fields_by_name['task_outputs']._options = None
  _TRIGGERNAMESPACEMODELRESPONSE.fields_by_name['task_outputs']._serialized_options = b'\340A\003'
  _TRIGGERASYNCNAMESPACEMODELREQUEST.fields_by_name['namespace_id']._options = None
  _TRIGGERASYNCNAMESPACEMODELREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _TRIGGERASYNCNAMESPACEMODELREQUEST.fields_by_name['model_id']._options = None
  _TRIGGERASYNCNAMESPACEMODELREQUEST.fields_by_name['model_id']._serialized_options = b'\340A\002'
  _TRIGGERASYNCNAMESPACEMODELREQUEST.fields_by_name['version']._options = None
  _TRIGGERASYNCNAMESPACEMODELREQUEST.fields_by_name['version']._serialized_options = b'\340A\002'
  _TRIGGERASYNCNAMESPACEMODELREQUEST.fields_by_name['task_inputs']._options = None
  _TRIGGERASYNCNAMESPACEMODELREQUEST.fields_by_name['task_inputs']._serialized_options = b'\340A\002'
  _TRIGGERASYNCNAMESPACEMODELRESPONSE.fields_by_name['operation']._options = None
  _TRIGGERASYNCNAMESPACEMODELRESPONSE.fields_by_name['operation']._serialized_options = b'\340A\003'
  _TRIGGERNAMESPACELATESTMODELREQUEST.fields_by_name['namespace_id']._options = None
  _TRIGGERNAMESPACELATESTMODELREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _TRIGGERNAMESPACELATESTMODELREQUEST.fields_by_name['model_id']._options = None
  _TRIGGERNAMESPACELATESTMODELREQUEST.fields_by_name['model_id']._serialized_options = b'\340A\002'
  _TRIGGERNAMESPACELATESTMODELREQUEST.fields_by_name['task_inputs']._options = None
  _TRIGGERNAMESPACELATESTMODELREQUEST.fields_by_name['task_inputs']._serialized_options = b'\340A\002'
  _TRIGGERNAMESPACELATESTMODELRESPONSE.fields_by_name['task']._options = None
  _TRIGGERNAMESPACELATESTMODELRESPONSE.fields_by_name['task']._serialized_options = b'\340A\003'
  _TRIGGERNAMESPACELATESTMODELRESPONSE.fields_by_name['task_outputs']._options = None
  _TRIGGERNAMESPACELATESTMODELRESPONSE.fields_by_name['task_outputs']._serialized_options = b'\340A\003'
  _TRIGGERASYNCNAMESPACELATESTMODELREQUEST.fields_by_name['namespace_id']._options = None
  _TRIGGERASYNCNAMESPACELATESTMODELREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _TRIGGERASYNCNAMESPACELATESTMODELREQUEST.fields_by_name['model_id']._options = None
  _TRIGGERASYNCNAMESPACELATESTMODELREQUEST.fields_by_name['model_id']._serialized_options = b'\340A\002'
  _TRIGGERASYNCNAMESPACELATESTMODELREQUEST.fields_by_name['task_inputs']._options = None
  _TRIGGERASYNCNAMESPACELATESTMODELREQUEST.fields_by_name['task_inputs']._serialized_options = b'\340A\002'
  _TRIGGERASYNCNAMESPACELATESTMODELRESPONSE.fields_by_name['operation']._options = None
  _TRIGGERASYNCNAMESPACELATESTMODELRESPONSE.fields_by_name['operation']._serialized_options = b'\340A\003'
  _TRIGGERNAMESPACEMODELBINARYFILEUPLOADREQUEST.fields_by_name['namespace_id']._options = None
  _TRIGGERNAMESPACEMODELBINARYFILEUPLOADREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _TRIGGERNAMESPACEMODELBINARYFILEUPLOADREQUEST.fields_by_name['model_id']._options = None
  _TRIGGERNAMESPACEMODELBINARYFILEUPLOADREQUEST.fields_by_name['model_id']._serialized_options = b'\340A\002'
  _TRIGGERNAMESPACEMODELBINARYFILEUPLOADREQUEST.fields_by_name['version']._options = None
  _TRIGGERNAMESPACEMODELBINARYFILEUPLOADREQUEST.fields_by_name['version']._serialized_options = b'\340A\002'
  _TRIGGERNAMESPACEMODELBINARYFILEUPLOADREQUEST.fields_by_name['task_input']._options = None
  _TRIGGERNAMESPACEMODELBINARYFILEUPLOADREQUEST.fields_by_name['task_input']._serialized_options = b'\340A\002'
  _TRIGGERNAMESPACEMODELBINARYFILEUPLOADRESPONSE.fields_by_name['task']._options = None
  _TRIGGERNAMESPACEMODELBINARYFILEUPLOADRESPONSE.fields_by_name['task']._serialized_options = b'\340A\002'
  _TRIGGERNAMESPACEMODELBINARYFILEUPLOADRESPONSE.fields_by_name['task_outputs']._options = None
  _TRIGGERNAMESPACEMODELBINARYFILEUPLOADRESPONSE.fields_by_name['task_outputs']._serialized_options = b'\340A\003'
  _TRIGGERNAMESPACELATESTMODELBINARYFILEUPLOADREQUEST.fields_by_name['namespace_id']._options = None
  _TRIGGERNAMESPACELATESTMODELBINARYFILEUPLOADREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _TRIGGERNAMESPACELATESTMODELBINARYFILEUPLOADREQUEST.fields_by_name['model_id']._options = None
  _TRIGGERNAMESPACELATESTMODELBINARYFILEUPLOADREQUEST.fields_by_name['model_id']._serialized_options = b'\340A\002'
  _TRIGGERNAMESPACELATESTMODELBINARYFILEUPLOADREQUEST.fields_by_name['task_input']._options = None
  _TRIGGERNAMESPACELATESTMODELBINARYFILEUPLOADREQUEST.fields_by_name['task_input']._serialized_options = b'\340A\002'
  _TRIGGERNAMESPACELATESTMODELBINARYFILEUPLOADRESPONSE.fields_by_name['task']._options = None
  _TRIGGERNAMESPACELATESTMODELBINARYFILEUPLOADRESPONSE.fields_by_name['task']._serialized_options = b'\340A\002'
  _TRIGGERNAMESPACELATESTMODELBINARYFILEUPLOADRESPONSE.fields_by_name['task_outputs']._options = None
  _TRIGGERNAMESPACELATESTMODELBINARYFILEUPLOADRESPONSE.fields_by_name['task_outputs']._serialized_options = b'\340A\003'
  _GETNAMESPACELATESTMODELOPERATIONREQUEST.fields_by_name['namespace_id']._options = None
  _GETNAMESPACELATESTMODELOPERATIONREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _GETNAMESPACELATESTMODELOPERATIONREQUEST.fields_by_name['model_id']._options = None
  _GETNAMESPACELATESTMODELOPERATIONREQUEST.fields_by_name['model_id']._serialized_options = b'\340A\002'
  _GETNAMESPACELATESTMODELOPERATIONREQUEST.fields_by_name['view']._options = None
  _GETNAMESPACELATESTMODELOPERATIONREQUEST.fields_by_name['view']._serialized_options = b'\340A\001'
  _GETNAMESPACELATESTMODELOPERATIONRESPONSE.fields_by_name['operation']._options = None
  _GETNAMESPACELATESTMODELOPERATIONRESPONSE.fields_by_name['operation']._serialized_options = b'\340A\003'
  _GETNAMESPACEMODELOPERATIONREQUEST.fields_by_name['namespace_id']._options = None
  _GETNAMESPACEMODELOPERATIONREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _GETNAMESPACEMODELOPERATIONREQUEST.fields_by_name['model_id']._options = None
  _GETNAMESPACEMODELOPERATIONREQUEST.fields_by_name['model_id']._serialized_options = b'\340A\002'
  _GETNAMESPACEMODELOPERATIONREQUEST.fields_by_name['version']._options = None
  _GETNAMESPACEMODELOPERATIONREQUEST.fields_by_name['version']._serialized_options = b'\340A\002'
  _GETNAMESPACEMODELOPERATIONREQUEST.fields_by_name['view']._options = None
  _GETNAMESPACEMODELOPERATIONREQUEST.fields_by_name['view']._serialized_options = b'\340A\001'
  _DEPLOYNAMESPACEMODELADMINREQUEST.fields_by_name['namespace_id']._options = None
  _DEPLOYNAMESPACEMODELADMINREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _DEPLOYNAMESPACEMODELADMINREQUEST.fields_by_name['model_id']._options = None
  _DEPLOYNAMESPACEMODELADMINREQUEST.fields_by_name['model_id']._serialized_options = b'\340A\002'
  _DEPLOYNAMESPACEMODELADMINREQUEST.fields_by_name['version']._options = None
  _DEPLOYNAMESPACEMODELADMINREQUEST.fields_by_name['version']._serialized_options = b'\340A\002'
  _DEPLOYNAMESPACEMODELADMINREQUEST.fields_by_name['digest']._options = None
  _DEPLOYNAMESPACEMODELADMINREQUEST.fields_by_name['digest']._serialized_options = b'\340A\001'
  _UNDEPLOYNAMESPACEMODELADMINREQUEST.fields_by_name['namespace_id']._options = None
  _UNDEPLOYNAMESPACEMODELADMINREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _UNDEPLOYNAMESPACEMODELADMINREQUEST.fields_by_name['model_id']._options = None
  _UNDEPLOYNAMESPACEMODELADMINREQUEST.fields_by_name['model_id']._serialized_options = b'\340A\002'
  _UNDEPLOYNAMESPACEMODELADMINREQUEST.fields_by_name['version']._options = None
  _UNDEPLOYNAMESPACEMODELADMINREQUEST.fields_by_name['version']._serialized_options = b'\340A\002'
  _UNDEPLOYNAMESPACEMODELADMINREQUEST.fields_by_name['digest']._options = None
  _UNDEPLOYNAMESPACEMODELADMINREQUEST.fields_by_name['digest']._serialized_options = b'\340A\001'
  _CREATEUSERMODELREQUEST.fields_by_name['parent']._options = None
  _CREATEUSERMODELREQUEST.fields_by_name['parent']._serialized_options = b'\222A\017\312>\014\372\002\tuser_name\340A\002\372A\030\022\026api.instill.tech/Model'
  _CREATEUSERMODELRESPONSE.fields_by_name['model']._options = None
  _CREATEUSERMODELRESPONSE.fields_by_name['model']._serialized_options = b'\340A\003'
  _LISTUSERMODELSREQUEST.fields_by_name['page_size']._options = None
  _LISTUSERMODELSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTUSERMODELSREQUEST.fields_by_name['page_token']._options = None
  _LISTUSERMODELSREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTUSERMODELSREQUEST.fields_by_name['view']._options = None
  _LISTUSERMODELSREQUEST.fields_by_name['view']._serialized_options = b'\340A\001'
  _LISTUSERMODELSREQUEST.fields_by_name['parent']._options = None
  _LISTUSERMODELSREQUEST.fields_by_name['parent']._serialized_options = b'\222A\017\312>\014\372\002\tuser_name\340A\002\372A\030\022\026api.instill.tech/Model'
  _LISTUSERMODELSREQUEST.fields_by_name['show_deleted']._options = None
  _LISTUSERMODELSREQUEST.fields_by_name['show_deleted']._serialized_options = b'\340A\001'
  _LISTUSERMODELSREQUEST.fields_by_name['filter']._options = None
  _LISTUSERMODELSREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTUSERMODELSREQUEST.fields_by_name['visibility']._options = None
  _LISTUSERMODELSREQUEST.fields_by_name['visibility']._serialized_options = b'\340A\001'
  _LISTUSERMODELSREQUEST.fields_by_name['order_by']._options = None
  _LISTUSERMODELSREQUEST.fields_by_name['order_by']._serialized_options = b'\340A\001'
  _LISTUSERMODELSRESPONSE.fields_by_name['models']._options = None
  _LISTUSERMODELSRESPONSE.fields_by_name['models']._serialized_options = b'\340A\003'
  _LISTUSERMODELSRESPONSE.fields_by_name['next_page_token']._options = None
  _LISTUSERMODELSRESPONSE.fields_by_name['next_page_token']._serialized_options = b'\340A\003'
  _LISTUSERMODELSRESPONSE.fields_by_name['total_size']._options = None
  _LISTUSERMODELSRESPONSE.fields_by_name['total_size']._serialized_options = b'\340A\003'
  _GETUSERMODELREQUEST.fields_by_name['name']._options = None
  _GETUSERMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\025\312>\022\372\002\017user_model_name\340A\002\372A\030\n\026api.instill.tech/Model'
  _GETUSERMODELREQUEST.fields_by_name['view']._options = None
  _GETUSERMODELREQUEST.fields_by_name['view']._serialized_options = b'\340A\001'
  _GETUSERMODELRESPONSE.fields_by_name['model']._options = None
  _GETUSERMODELRESPONSE.fields_by_name['model']._serialized_options = b'\340A\003'
  _UPDATEUSERMODELREQUEST.fields_by_name['model']._options = None
  _UPDATEUSERMODELREQUEST.fields_by_name['model']._serialized_options = b'\340A\002'
  _UPDATEUSERMODELREQUEST.fields_by_name['update_mask']._options = None
  _UPDATEUSERMODELREQUEST.fields_by_name['update_mask']._serialized_options = b'\340A\002'
  _UPDATEUSERMODELRESPONSE.fields_by_name['model']._options = None
  _UPDATEUSERMODELRESPONSE.fields_by_name['model']._serialized_options = b'\340A\003'
  _DELETEUSERMODELREQUEST.fields_by_name['name']._options = None
  _DELETEUSERMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\025\312>\022\372\002\017user_model_name\340A\002\372A\030\n\026api.instill.tech/Model'
  _RENAMEUSERMODELREQUEST.fields_by_name['name']._options = None
  _RENAMEUSERMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\025\312>\022\372\002\017user_model_name\340A\002\372A\030\n\026api.instill.tech/Model'
  _RENAMEUSERMODELREQUEST.fields_by_name['new_model_id']._options = None
  _RENAMEUSERMODELREQUEST.fields_by_name['new_model_id']._serialized_options = b'\340A\002'
  _RENAMEUSERMODELRESPONSE.fields_by_name['model']._options = None
  _RENAMEUSERMODELRESPONSE.fields_by_name['model']._serialized_options = b'\340A\003'
  _WATCHUSERMODELREQUEST.fields_by_name['name']._options = None
  _WATCHUSERMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\025\312>\022\372\002\017user_model_name\340A\002\372A\030\n\026api.instill.tech/Model'
  _WATCHUSERMODELREQUEST.fields_by_name['version']._options = None
  _WATCHUSERMODELREQUEST.fields_by_name['version']._serialized_options = b'\340A\002'
  _WATCHUSERMODELRESPONSE.fields_by_name['state']._options = None
  _WATCHUSERMODELRESPONSE.fields_by_name['state']._serialized_options = b'\340A\003'
  _WATCHUSERMODELRESPONSE.fields_by_name['message']._options = None
  _WATCHUSERMODELRESPONSE.fields_by_name['message']._serialized_options = b'\340A\003'
  _WATCHUSERLATESTMODELREQUEST.fields_by_name['name']._options = None
  _WATCHUSERLATESTMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\025\312>\022\372\002\017user_model_name\340A\002\372A\030\n\026api.instill.tech/Model'
  _WATCHUSERLATESTMODELRESPONSE.fields_by_name['state']._options = None
  _WATCHUSERLATESTMODELRESPONSE.fields_by_name['state']._serialized_options = b'\340A\003'
  _WATCHUSERLATESTMODELRESPONSE.fields_by_name['message']._options = None
  _WATCHUSERLATESTMODELRESPONSE.fields_by_name['message']._serialized_options = b'\340A\003'
  _LISTUSERMODELVERSIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTUSERMODELVERSIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTUSERMODELVERSIONSREQUEST.fields_by_name['page']._options = None
  _LISTUSERMODELVERSIONSREQUEST.fields_by_name['page']._serialized_options = b'\340A\001'
  _LISTUSERMODELVERSIONSREQUEST.fields_by_name['name']._options = None
  _LISTUSERMODELVERSIONSREQUEST.fields_by_name['name']._serialized_options = b'\222A\025\312>\022\372\002\017user_model_name\340A\002\372A\030\n\026api.instill.tech/Model'
  _LISTUSERMODELVERSIONSRESPONSE.fields_by_name['versions']._options = None
  _LISTUSERMODELVERSIONSRESPONSE.fields_by_name['versions']._serialized_options = b'\340A\003'
  _LISTUSERMODELVERSIONSRESPONSE.fields_by_name['total_size']._options = None
  _LISTUSERMODELVERSIONSRESPONSE.fields_by_name['total_size']._serialized_options = b'\340A\003'
  _LISTUSERMODELVERSIONSRESPONSE.fields_by_name['page_size']._options = None
  _LISTUSERMODELVERSIONSRESPONSE.fields_by_name['page_size']._serialized_options = b'\340A\003'
  _LISTUSERMODELVERSIONSRESPONSE.fields_by_name['page']._options = None
  _LISTUSERMODELVERSIONSRESPONSE.fields_by_name['page']._serialized_options = b'\340A\003'
  _DELETEUSERMODELVERSIONREQUEST.fields_by_name['name']._options = None
  _DELETEUSERMODELVERSIONREQUEST.fields_by_name['name']._serialized_options = b'\222A\025\312>\022\372\002\017user_model_name\340A\002\372A\030\n\026api.instill.tech/Model'
  _DELETEUSERMODELVERSIONREQUEST.fields_by_name['version']._options = None
  _DELETEUSERMODELVERSIONREQUEST.fields_by_name['version']._serialized_options = b'\340A\002'
  _TRIGGERUSERMODELREQUEST.fields_by_name['name']._options = None
  _TRIGGERUSERMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\025\312>\022\372\002\017user_model_name\340A\002\372A\030\n\026api.instill.tech/Model'
  _TRIGGERUSERMODELREQUEST.fields_by_name['version']._options = None
  _TRIGGERUSERMODELREQUEST.fields_by_name['version']._serialized_options = b'\340A\002'
  _TRIGGERUSERMODELREQUEST.fields_by_name['task_inputs']._options = None
  _TRIGGERUSERMODELREQUEST.fields_by_name['task_inputs']._serialized_options = b'\340A\002'
  _TRIGGERUSERMODELRESPONSE.fields_by_name['task']._options = None
  _TRIGGERUSERMODELRESPONSE.fields_by_name['task']._serialized_options = b'\340A\003'
  _TRIGGERUSERMODELRESPONSE.fields_by_name['task_outputs']._options = None
  _TRIGGERUSERMODELRESPONSE.fields_by_name['task_outputs']._serialized_options = b'\340A\003'
  _TRIGGERASYNCUSERMODELREQUEST.fields_by_name['name']._options = None
  _TRIGGERASYNCUSERMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\025\312>\022\372\002\017user_model_name\340A\002\372A\030\n\026api.instill.tech/Model'
  _TRIGGERASYNCUSERMODELREQUEST.fields_by_name['version']._options = None
  _TRIGGERASYNCUSERMODELREQUEST.fields_by_name['version']._serialized_options = b'\340A\002'
  _TRIGGERASYNCUSERMODELREQUEST.fields_by_name['task_inputs']._options = None
  _TRIGGERASYNCUSERMODELREQUEST.fields_by_name['task_inputs']._serialized_options = b'\340A\002'
  _TRIGGERASYNCUSERMODELRESPONSE.fields_by_name['operation']._options = None
  _TRIGGERASYNCUSERMODELRESPONSE.fields_by_name['operation']._serialized_options = b'\340A\003'
  _TRIGGERUSERLATESTMODELREQUEST.fields_by_name['name']._options = None
  _TRIGGERUSERLATESTMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\025\312>\022\372\002\017user_model_name\340A\002\372A\030\n\026api.instill.tech/Model'
  _TRIGGERUSERLATESTMODELREQUEST.fields_by_name['task_inputs']._options = None
  _TRIGGERUSERLATESTMODELREQUEST.fields_by_name['task_inputs']._serialized_options = b'\340A\002'
  _TRIGGERUSERLATESTMODELRESPONSE.fields_by_name['task']._options = None
  _TRIGGERUSERLATESTMODELRESPONSE.fields_by_name['task']._serialized_options = b'\340A\003'
  _TRIGGERUSERLATESTMODELRESPONSE.fields_by_name['task_outputs']._options = None
  _TRIGGERUSERLATESTMODELRESPONSE.fields_by_name['task_outputs']._serialized_options = b'\340A\003'
  _TRIGGERASYNCUSERLATESTMODELREQUEST.fields_by_name['name']._options = None
  _TRIGGERASYNCUSERLATESTMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\025\312>\022\372\002\017user_model_name\340A\002\372A\030\n\026api.instill.tech/Model'
  _TRIGGERASYNCUSERLATESTMODELREQUEST.fields_by_name['task_inputs']._options = None
  _TRIGGERASYNCUSERLATESTMODELREQUEST.fields_by_name['task_inputs']._serialized_options = b'\340A\002'
  _TRIGGERASYNCUSERLATESTMODELRESPONSE.fields_by_name['operation']._options = None
  _TRIGGERASYNCUSERLATESTMODELRESPONSE.fields_by_name['operation']._serialized_options = b'\340A\003'
  _TRIGGERUSERMODELBINARYFILEUPLOADREQUEST.fields_by_name['name']._options = None
  _TRIGGERUSERMODELBINARYFILEUPLOADREQUEST.fields_by_name['name']._serialized_options = b'\222A\025\312>\022\372\002\017user_model_name\340A\002\372A\030\n\026api.instill.tech/Model'
  _TRIGGERUSERMODELBINARYFILEUPLOADREQUEST.fields_by_name['version']._options = None
  _TRIGGERUSERMODELBINARYFILEUPLOADREQUEST.fields_by_name['version']._serialized_options = b'\340A\002'
  _TRIGGERUSERMODELBINARYFILEUPLOADREQUEST.fields_by_name['task_inputs']._options = None
  _TRIGGERUSERMODELBINARYFILEUPLOADREQUEST.fields_by_name['task_inputs']._serialized_options = b'\340A\002'
  _TRIGGERUSERMODELBINARYFILEUPLOADRESPONSE.fields_by_name['task']._options = None
  _TRIGGERUSERMODELBINARYFILEUPLOADRESPONSE.fields_by_name['task']._serialized_options = b'\340A\002'
  _TRIGGERUSERMODELBINARYFILEUPLOADRESPONSE.fields_by_name['task_outputs']._options = None
  _TRIGGERUSERMODELBINARYFILEUPLOADRESPONSE.fields_by_name['task_outputs']._serialized_options = b'\340A\003'
  _CREATEORGANIZATIONMODELREQUEST.fields_by_name['parent']._options = None
  _CREATEORGANIZATIONMODELREQUEST.fields_by_name['parent']._serialized_options = b'\222A\027\312>\024\372\002\021organization_name\340A\002\372A\030\022\026api.instill.tech/Model'
  _CREATEORGANIZATIONMODELRESPONSE.fields_by_name['model']._options = None
  _CREATEORGANIZATIONMODELRESPONSE.fields_by_name['model']._serialized_options = b'\340A\003'
  _LISTORGANIZATIONMODELSREQUEST.fields_by_name['page_size']._options = None
  _LISTORGANIZATIONMODELSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTORGANIZATIONMODELSREQUEST.fields_by_name['page_token']._options = None
  _LISTORGANIZATIONMODELSREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTORGANIZATIONMODELSREQUEST.fields_by_name['view']._options = None
  _LISTORGANIZATIONMODELSREQUEST.fields_by_name['view']._serialized_options = b'\340A\001'
  _LISTORGANIZATIONMODELSREQUEST.fields_by_name['parent']._options = None
  _LISTORGANIZATIONMODELSREQUEST.fields_by_name['parent']._serialized_options = b'\222A\027\312>\024\372\002\021organization_name\340A\002\372A\030\022\026api.instill.tech/Model'
  _LISTORGANIZATIONMODELSREQUEST.fields_by_name['show_deleted']._options = None
  _LISTORGANIZATIONMODELSREQUEST.fields_by_name['show_deleted']._serialized_options = b'\340A\001'
  _LISTORGANIZATIONMODELSREQUEST.fields_by_name['filter']._options = None
  _LISTORGANIZATIONMODELSREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTORGANIZATIONMODELSREQUEST.fields_by_name['visibility']._options = None
  _LISTORGANIZATIONMODELSREQUEST.fields_by_name['visibility']._serialized_options = b'\340A\001'
  _LISTORGANIZATIONMODELSREQUEST.fields_by_name['order_by']._options = None
  _LISTORGANIZATIONMODELSREQUEST.fields_by_name['order_by']._serialized_options = b'\340A\001'
  _LISTORGANIZATIONMODELSRESPONSE.fields_by_name['models']._options = None
  _LISTORGANIZATIONMODELSRESPONSE.fields_by_name['models']._serialized_options = b'\340A\003'
  _LISTORGANIZATIONMODELSRESPONSE.fields_by_name['next_page_token']._options = None
  _LISTORGANIZATIONMODELSRESPONSE.fields_by_name['next_page_token']._serialized_options = b'\340A\003'
  _LISTORGANIZATIONMODELSRESPONSE.fields_by_name['total_size']._options = None
  _LISTORGANIZATIONMODELSRESPONSE.fields_by_name['total_size']._serialized_options = b'\340A\003'
  _GETORGANIZATIONMODELREQUEST.fields_by_name['name']._options = None
  _GETORGANIZATIONMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\035\312>\032\372\002\027organization_model_name\340A\002\372A\030\n\026api.instill.tech/Model'
  _GETORGANIZATIONMODELREQUEST.fields_by_name['view']._options = None
  _GETORGANIZATIONMODELREQUEST.fields_by_name['view']._serialized_options = b'\340A\001'
  _GETORGANIZATIONMODELRESPONSE.fields_by_name['model']._options = None
  _GETORGANIZATIONMODELRESPONSE.fields_by_name['model']._serialized_options = b'\340A\003'
  _UPDATEORGANIZATIONMODELREQUEST.fields_by_name['model']._options = None
  _UPDATEORGANIZATIONMODELREQUEST.fields_by_name['model']._serialized_options = b'\340A\002'
  _UPDATEORGANIZATIONMODELREQUEST.fields_by_name['update_mask']._options = None
  _UPDATEORGANIZATIONMODELREQUEST.fields_by_name['update_mask']._serialized_options = b'\340A\002'
  _UPDATEORGANIZATIONMODELRESPONSE.fields_by_name['model']._options = None
  _UPDATEORGANIZATIONMODELRESPONSE.fields_by_name['model']._serialized_options = b'\340A\003'
  _DELETEORGANIZATIONMODELREQUEST.fields_by_name['name']._options = None
  _DELETEORGANIZATIONMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\035\312>\032\372\002\027organization_model_name\340A\002\372A\030\n\026api.instill.tech/Model'
  _RENAMEORGANIZATIONMODELREQUEST.fields_by_name['name']._options = None
  _RENAMEORGANIZATIONMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\035\312>\032\372\002\027organization_model_name\340A\002\372A\030\n\026api.instill.tech/Model'
  _RENAMEORGANIZATIONMODELREQUEST.fields_by_name['new_model_id']._options = None
  _RENAMEORGANIZATIONMODELREQUEST.fields_by_name['new_model_id']._serialized_options = b'\340A\002'
  _RENAMEORGANIZATIONMODELRESPONSE.fields_by_name['model']._options = None
  _RENAMEORGANIZATIONMODELRESPONSE.fields_by_name['model']._serialized_options = b'\340A\003'
  _WATCHORGANIZATIONMODELREQUEST.fields_by_name['name']._options = None
  _WATCHORGANIZATIONMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\035\312>\032\372\002\027organization_model_name\340A\002\372A\030\n\026api.instill.tech/Model'
  _WATCHORGANIZATIONMODELREQUEST.fields_by_name['version']._options = None
  _WATCHORGANIZATIONMODELREQUEST.fields_by_name['version']._serialized_options = b'\340A\002'
  _WATCHORGANIZATIONMODELRESPONSE.fields_by_name['state']._options = None
  _WATCHORGANIZATIONMODELRESPONSE.fields_by_name['state']._serialized_options = b'\340A\003'
  _WATCHORGANIZATIONMODELRESPONSE.fields_by_name['message']._options = None
  _WATCHORGANIZATIONMODELRESPONSE.fields_by_name['message']._serialized_options = b'\340A\003'
  _WATCHORGANIZATIONLATESTMODELREQUEST.fields_by_name['name']._options = None
  _WATCHORGANIZATIONLATESTMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\035\312>\032\372\002\027organization_model_name\340A\002\372A\030\n\026api.instill.tech/Model'
  _WATCHORGANIZATIONLATESTMODELRESPONSE.fields_by_name['state']._options = None
  _WATCHORGANIZATIONLATESTMODELRESPONSE.fields_by_name['state']._serialized_options = b'\340A\003'
  _WATCHORGANIZATIONLATESTMODELRESPONSE.fields_by_name['message']._options = None
  _WATCHORGANIZATIONLATESTMODELRESPONSE.fields_by_name['message']._serialized_options = b'\340A\003'
  _LISTORGANIZATIONMODELVERSIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTORGANIZATIONMODELVERSIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTORGANIZATIONMODELVERSIONSREQUEST.fields_by_name['page']._options = None
  _LISTORGANIZATIONMODELVERSIONSREQUEST.fields_by_name['page']._serialized_options = b'\340A\001'
  _LISTORGANIZATIONMODELVERSIONSREQUEST.fields_by_name['name']._options = None
  _LISTORGANIZATIONMODELVERSIONSREQUEST.fields_by_name['name']._serialized_options = b'\222A\035\312>\032\372\002\027organization_model_name\340A\002\372A\030\n\026api.instill.tech/Model'
  _LISTORGANIZATIONMODELVERSIONSRESPONSE.fields_by_name['versions']._options = None
  _LISTORGANIZATIONMODELVERSIONSRESPONSE.fields_by_name['versions']._serialized_options = b'\340A\003'
  _LISTORGANIZATIONMODELVERSIONSRESPONSE.fields_by_name['total_size']._options = None
  _LISTORGANIZATIONMODELVERSIONSRESPONSE.fields_by_name['total_size']._serialized_options = b'\340A\003'
  _LISTORGANIZATIONMODELVERSIONSRESPONSE.fields_by_name['page_size']._options = None
  _LISTORGANIZATIONMODELVERSIONSRESPONSE.fields_by_name['page_size']._serialized_options = b'\340A\003'
  _LISTORGANIZATIONMODELVERSIONSRESPONSE.fields_by_name['page']._options = None
  _LISTORGANIZATIONMODELVERSIONSRESPONSE.fields_by_name['page']._serialized_options = b'\340A\003'
  _DELETEORGANIZATIONMODELVERSIONREQUEST.fields_by_name['name']._options = None
  _DELETEORGANIZATIONMODELVERSIONREQUEST.fields_by_name['name']._serialized_options = b'\222A\035\312>\032\372\002\027organization_model_name\340A\002\372A\030\n\026api.instill.tech/Model'
  _DELETEORGANIZATIONMODELVERSIONREQUEST.fields_by_name['version']._options = None
  _DELETEORGANIZATIONMODELVERSIONREQUEST.fields_by_name['version']._serialized_options = b'\340A\002'
  _TRIGGERORGANIZATIONMODELREQUEST.fields_by_name['name']._options = None
  _TRIGGERORGANIZATIONMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\035\312>\032\372\002\027organization_model_name\340A\002\372A\030\n\026api.instill.tech/Model'
  _TRIGGERORGANIZATIONMODELREQUEST.fields_by_name['version']._options = None
  _TRIGGERORGANIZATIONMODELREQUEST.fields_by_name['version']._serialized_options = b'\340A\002'
  _TRIGGERORGANIZATIONMODELREQUEST.fields_by_name['task_inputs']._options = None
  _TRIGGERORGANIZATIONMODELREQUEST.fields_by_name['task_inputs']._serialized_options = b'\340A\002'
  _TRIGGERORGANIZATIONMODELRESPONSE.fields_by_name['task']._options = None
  _TRIGGERORGANIZATIONMODELRESPONSE.fields_by_name['task']._serialized_options = b'\340A\003'
  _TRIGGERORGANIZATIONMODELRESPONSE.fields_by_name['task_outputs']._options = None
  _TRIGGERORGANIZATIONMODELRESPONSE.fields_by_name['task_outputs']._serialized_options = b'\340A\003'
  _TRIGGERASYNCORGANIZATIONMODELREQUEST.fields_by_name['name']._options = None
  _TRIGGERASYNCORGANIZATIONMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\035\312>\032\372\002\027organization_model_name\340A\002\372A\030\n\026api.instill.tech/Model'
  _TRIGGERASYNCORGANIZATIONMODELREQUEST.fields_by_name['version']._options = None
  _TRIGGERASYNCORGANIZATIONMODELREQUEST.fields_by_name['version']._serialized_options = b'\340A\002'
  _TRIGGERASYNCORGANIZATIONMODELREQUEST.fields_by_name['task_inputs']._options = None
  _TRIGGERASYNCORGANIZATIONMODELREQUEST.fields_by_name['task_inputs']._serialized_options = b'\340A\002'
  _TRIGGERASYNCORGANIZATIONMODELRESPONSE.fields_by_name['operation']._options = None
  _TRIGGERASYNCORGANIZATIONMODELRESPONSE.fields_by_name['operation']._serialized_options = b'\340A\003'
  _TRIGGERORGANIZATIONLATESTMODELREQUEST.fields_by_name['name']._options = None
  _TRIGGERORGANIZATIONLATESTMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\035\312>\032\372\002\027organization_model_name\340A\002\372A\030\n\026api.instill.tech/Model'
  _TRIGGERORGANIZATIONLATESTMODELREQUEST.fields_by_name['task_inputs']._options = None
  _TRIGGERORGANIZATIONLATESTMODELREQUEST.fields_by_name['task_inputs']._serialized_options = b'\340A\002'
  _TRIGGERORGANIZATIONLATESTMODELRESPONSE.fields_by_name['task']._options = None
  _TRIGGERORGANIZATIONLATESTMODELRESPONSE.fields_by_name['task']._serialized_options = b'\340A\003'
  _TRIGGERORGANIZATIONLATESTMODELRESPONSE.fields_by_name['task_outputs']._options = None
  _TRIGGERORGANIZATIONLATESTMODELRESPONSE.fields_by_name['task_outputs']._serialized_options = b'\340A\003'
  _TRIGGERASYNCORGANIZATIONLATESTMODELREQUEST.fields_by_name['name']._options = None
  _TRIGGERASYNCORGANIZATIONLATESTMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\035\312>\032\372\002\027organization_model_name\340A\002\372A\030\n\026api.instill.tech/Model'
  _TRIGGERASYNCORGANIZATIONLATESTMODELREQUEST.fields_by_name['task_inputs']._options = None
  _TRIGGERASYNCORGANIZATIONLATESTMODELREQUEST.fields_by_name['task_inputs']._serialized_options = b'\340A\002'
  _TRIGGERASYNCORGANIZATIONLATESTMODELRESPONSE.fields_by_name['operation']._options = None
  _TRIGGERASYNCORGANIZATIONLATESTMODELRESPONSE.fields_by_name['operation']._serialized_options = b'\340A\003'
  _TRIGGERORGANIZATIONMODELBINARYFILEUPLOADREQUEST.fields_by_name['name']._options = None
  _TRIGGERORGANIZATIONMODELBINARYFILEUPLOADREQUEST.fields_by_name['name']._serialized_options = b'\222A\035\312>\032\372\002\027organization_model_name\340A\002\372A\030\n\026api.instill.tech/Model'
  _TRIGGERORGANIZATIONMODELBINARYFILEUPLOADREQUEST.fields_by_name['version']._options = None
  _TRIGGERORGANIZATIONMODELBINARYFILEUPLOADREQUEST.fields_by_name['version']._serialized_options = b'\340A\002'
  _TRIGGERORGANIZATIONMODELBINARYFILEUPLOADREQUEST.fields_by_name['task_inputs']._options = None
  _TRIGGERORGANIZATIONMODELBINARYFILEUPLOADREQUEST.fields_by_name['task_inputs']._serialized_options = b'\340A\002'
  _TRIGGERORGANIZATIONMODELBINARYFILEUPLOADRESPONSE.fields_by_name['task']._options = None
  _TRIGGERORGANIZATIONMODELBINARYFILEUPLOADRESPONSE.fields_by_name['task']._serialized_options = b'\340A\002'
  _GETMODELOPERATIONREQUEST.fields_by_name['operation_id']._options = None
  _GETMODELOPERATIONREQUEST.fields_by_name['operation_id']._serialized_options = b'\340A\002'
  _GETMODELOPERATIONREQUEST.fields_by_name['view']._options = None
  _GETMODELOPERATIONREQUEST.fields_by_name['view']._serialized_options = b'\030\001\340A\001'
  _GETMODELOPERATIONRESPONSE.fields_by_name['operation']._options = None
  _GETMODELOPERATIONRESPONSE.fields_by_name['operation']._serialized_options = b'\340A\003'
  _GETUSERLATESTMODELOPERATIONREQUEST.fields_by_name['name']._options = None
  _GETUSERLATESTMODELOPERATIONREQUEST.fields_by_name['name']._serialized_options = b'\222A\025\312>\022\372\002\017user_model_name\340A\002\372A\030\n\026api.instill.tech/Model'
  _GETUSERLATESTMODELOPERATIONREQUEST.fields_by_name['view']._options = None
  _GETUSERLATESTMODELOPERATIONREQUEST.fields_by_name['view']._serialized_options = b'\340A\001'
  _GETUSERLATESTMODELOPERATIONRESPONSE.fields_by_name['operation']._options = None
  _GETUSERLATESTMODELOPERATIONRESPONSE.fields_by_name['operation']._serialized_options = b'\340A\003'
  _GETORGANIZATIONLATESTMODELOPERATIONREQUEST.fields_by_name['name']._options = None
  _GETORGANIZATIONLATESTMODELOPERATIONREQUEST.fields_by_name['name']._serialized_options = b'\222A\035\312>\032\372\002\027organization_model_name\340A\002\372A\030\n\026api.instill.tech/Model'
  _GETORGANIZATIONLATESTMODELOPERATIONREQUEST.fields_by_name['view']._options = None
  _GETORGANIZATIONLATESTMODELOPERATIONREQUEST.fields_by_name['view']._serialized_options = b'\340A\001'
  _GETORGANIZATIONLATESTMODELOPERATIONRESPONSE.fields_by_name['operation']._options = None
  _GETORGANIZATIONLATESTMODELOPERATIONRESPONSE.fields_by_name['operation']._serialized_options = b'\340A\003'
  _LISTAVAILABLEREGIONSRESPONSE.fields_by_name['regions']._options = None
  _LISTAVAILABLEREGIONSRESPONSE.fields_by_name['regions']._serialized_options = b'\340A\003'
  _LISTMODELSADMINREQUEST.fields_by_name['page_size']._options = None
  _LISTMODELSADMINREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTMODELSADMINREQUEST.fields_by_name['page_token']._options = None
  _LISTMODELSADMINREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTMODELSADMINREQUEST.fields_by_name['view']._options = None
  _LISTMODELSADMINREQUEST.fields_by_name['view']._serialized_options = b'\340A\001'
  _LISTMODELSADMINREQUEST.fields_by_name['show_deleted']._options = None
  _LISTMODELSADMINREQUEST.fields_by_name['show_deleted']._serialized_options = b'\340A\001'
  _LISTMODELSADMINREQUEST.fields_by_name['filter']._options = None
  _LISTMODELSADMINREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LOOKUPMODELADMINREQUEST.fields_by_name['permalink']._options = None
  _LOOKUPMODELADMINREQUEST.fields_by_name['permalink']._serialized_options = b'\340A\002'
  _LOOKUPMODELADMINREQUEST.fields_by_name['view']._options = None
  _LOOKUPMODELADMINREQUEST.fields_by_name['view']._serialized_options = b'\340A\001'
  _DEPLOYUSERMODELADMINREQUEST.fields_by_name['name']._options = None
  _DEPLOYUSERMODELADMINREQUEST.fields_by_name['name']._serialized_options = b'\222A\025\312>\022\372\002\017user_model_name\340A\002\372A\030\n\026api.instill.tech/Model'
  _DEPLOYUSERMODELADMINREQUEST.fields_by_name['version']._options = None
  _DEPLOYUSERMODELADMINREQUEST.fields_by_name['version']._serialized_options = b'\340A\002'
  _DEPLOYUSERMODELADMINREQUEST.fields_by_name['digest']._options = None
  _DEPLOYUSERMODELADMINREQUEST.fields_by_name['digest']._serialized_options = b'\340A\001'
  _DEPLOYORGANIZATIONMODELADMINREQUEST.fields_by_name['name']._options = None
  _DEPLOYORGANIZATIONMODELADMINREQUEST.fields_by_name['name']._serialized_options = b'\222A\035\312>\032\372\002\027organization_model_name\340A\002\372A\030\n\026api.instill.tech/Model'
  _DEPLOYORGANIZATIONMODELADMINREQUEST.fields_by_name['version']._options = None
  _DEPLOYORGANIZATIONMODELADMINREQUEST.fields_by_name['version']._serialized_options = b'\340A\002'
  _DEPLOYORGANIZATIONMODELADMINREQUEST.fields_by_name['digest']._options = None
  _DEPLOYORGANIZATIONMODELADMINREQUEST.fields_by_name['digest']._serialized_options = b'\340A\001'
  _UNDEPLOYUSERMODELADMINREQUEST.fields_by_name['name']._options = None
  _UNDEPLOYUSERMODELADMINREQUEST.fields_by_name['name']._serialized_options = b'\222A\025\312>\022\372\002\017user_model_name\340A\002\372A\030\n\026api.instill.tech/Model'
  _UNDEPLOYUSERMODELADMINREQUEST.fields_by_name['version']._options = None
  _UNDEPLOYUSERMODELADMINREQUEST.fields_by_name['version']._serialized_options = b'\340A\002'
  _UNDEPLOYUSERMODELADMINREQUEST.fields_by_name['digest']._options = None
  _UNDEPLOYUSERMODELADMINREQUEST.fields_by_name['digest']._serialized_options = b'\340A\001'
  _UNDEPLOYORGANIZATIONMODELADMINREQUEST.fields_by_name['name']._options = None
  _UNDEPLOYORGANIZATIONMODELADMINREQUEST.fields_by_name['name']._serialized_options = b'\222A\035\312>\032\372\002\027organization_model_name\340A\002\372A\030\n\026api.instill.tech/Model'
  _UNDEPLOYORGANIZATIONMODELADMINREQUEST.fields_by_name['version']._options = None
  _UNDEPLOYORGANIZATIONMODELADMINREQUEST.fields_by_name['version']._serialized_options = b'\340A\002'
  _UNDEPLOYORGANIZATIONMODELADMINREQUEST.fields_by_name['digest']._options = None
  _UNDEPLOYORGANIZATIONMODELADMINREQUEST.fields_by_name['digest']._serialized_options = b'\340A\001'
  _MODELRUN.fields_by_name['uid']._options = None
  _MODELRUN.fields_by_name['uid']._serialized_options = b'\340A\003'
  _MODELRUN.fields_by_name['model_uid']._options = None
  _MODELRUN.fields_by_name['model_uid']._serialized_options = b'\340A\003'
  _MODELRUN.fields_by_name['status']._options = None
  _MODELRUN.fields_by_name['status']._serialized_options = b'\340A\003'
  _MODELRUN.fields_by_name['source']._options = None
  _MODELRUN.fields_by_name['source']._serialized_options = b'\340A\003'
  _MODELRUN.fields_by_name['total_duration']._options = None
  _MODELRUN.fields_by_name['total_duration']._serialized_options = b'\340A\003\340A\001'
  _MODELRUN.fields_by_name['end_time']._options = None
  _MODELRUN.fields_by_name['end_time']._serialized_options = b'\340A\003\340A\001'
  _MODELRUN.fields_by_name['runner_id']._options = None
  _MODELRUN.fields_by_name['runner_id']._serialized_options = b'\340A\003\340A\001'
  _MODELRUN.fields_by_name['credit_amount']._options = None
  _MODELRUN.fields_by_name['credit_amount']._serialized_options = b'\340A\003\340A\001'
  _MODELRUN.fields_by_name['error']._options = None
  _MODELRUN.fields_by_name['error']._serialized_options = b'\340A\003\340A\001'
  _MODELRUN.fields_by_name['create_time']._options = None
  _MODELRUN.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _MODELRUN.fields_by_name['update_time']._options = None
  _MODELRUN.fields_by_name['update_time']._serialized_options = b'\340A\003'
  _MODELRUN.fields_by_name['version']._options = None
  _MODELRUN.fields_by_name['version']._serialized_options = b'\340A\003'
  _MODELRUN.fields_by_name['task_inputs']._options = None
  _MODELRUN.fields_by_name['task_inputs']._serialized_options = b'\340A\003'
  _MODELRUN.fields_by_name['task_outputs']._options = None
  _MODELRUN.fields_by_name['task_outputs']._serialized_options = b'\340A\003'
  _MODELRUN.fields_by_name['model_id']._options = None
  _MODELRUN.fields_by_name['model_id']._serialized_options = b'\340A\003\340A\001'
  _LISTMODELRUNSREQUEST.fields_by_name['page_size']._options = None
  _LISTMODELRUNSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTMODELRUNSREQUEST.fields_by_name['page']._options = None
  _LISTMODELRUNSREQUEST.fields_by_name['page']._serialized_options = b'\340A\001'
  _LISTMODELRUNSREQUEST.fields_by_name['order_by']._options = None
  _LISTMODELRUNSREQUEST.fields_by_name['order_by']._serialized_options = b'\340A\001'
  _LISTMODELRUNSREQUEST.fields_by_name['namespace_id']._options = None
  _LISTMODELRUNSREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _LISTMODELRUNSREQUEST.fields_by_name['model_id']._options = None
  _LISTMODELRUNSREQUEST.fields_by_name['model_id']._serialized_options = b'\340A\002'
  _LISTMODELRUNSREQUEST.fields_by_name['filter']._options = None
  _LISTMODELRUNSREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTMODELRUNSBYCREDITOWNERREQUEST.fields_by_name['page_size']._options = None
  _LISTMODELRUNSBYCREDITOWNERREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTMODELRUNSBYCREDITOWNERREQUEST.fields_by_name['page']._options = None
  _LISTMODELRUNSBYCREDITOWNERREQUEST.fields_by_name['page']._serialized_options = b'\340A\001'
  _LISTMODELRUNSBYCREDITOWNERREQUEST.fields_by_name['order_by']._options = None
  _LISTMODELRUNSBYCREDITOWNERREQUEST.fields_by_name['order_by']._serialized_options = b'\340A\001'
  _LISTMODELRUNSBYCREDITOWNERREQUEST.fields_by_name['filter']._options = None
  _LISTMODELRUNSBYCREDITOWNERREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTMODELRUNSRESPONSE.fields_by_name['runs']._options = None
  _LISTMODELRUNSRESPONSE.fields_by_name['runs']._serialized_options = b'\340A\003'
  _LISTMODELRUNSRESPONSE.fields_by_name['total_size']._options = None
  _LISTMODELRUNSRESPONSE.fields_by_name['total_size']._serialized_options = b'\340A\003'
  _LISTMODELRUNSRESPONSE.fields_by_name['page_size']._options = None
  _LISTMODELRUNSRESPONSE.fields_by_name['page_size']._serialized_options = b'\340A\003'
  _LISTMODELRUNSRESPONSE.fields_by_name['page']._options = None
  _LISTMODELRUNSRESPONSE.fields_by_name['page']._serialized_options = b'\340A\003'
  _LISTMODELRUNSBYCREDITOWNERRESPONSE.fields_by_name['runs']._options = None
  _LISTMODELRUNSBYCREDITOWNERRESPONSE.fields_by_name['runs']._serialized_options = b'\340A\003'
  _LISTMODELRUNSBYCREDITOWNERRESPONSE.fields_by_name['total_size']._options = None
  _LISTMODELRUNSBYCREDITOWNERRESPONSE.fields_by_name['total_size']._serialized_options = b'\340A\003'
  _LISTMODELRUNSBYCREDITOWNERRESPONSE.fields_by_name['page_size']._options = None
  _LISTMODELRUNSBYCREDITOWNERRESPONSE.fields_by_name['page_size']._serialized_options = b'\340A\003'
  _LISTMODELRUNSBYCREDITOWNERRESPONSE.fields_by_name['page']._options = None
  _LISTMODELRUNSBYCREDITOWNERRESPONSE.fields_by_name['page']._serialized_options = b'\340A\003'
  _globals['_STATE']._serialized_start=23803
  _globals['_STATE']._serialized_end=23975
  _globals['_LIVENESSREQUEST']._serialized_start=513
  _globals['_LIVENESSREQUEST']._serialized_end=662
  _globals['_LIVENESSRESPONSE']._serialized_start=664
  _globals['_LIVENESSRESPONSE']._serialized_end=782
  _globals['_READINESSREQUEST']._serialized_start=785
  _globals['_READINESSREQUEST']._serialized_end=935
  _globals['_READINESSRESPONSE']._serialized_start=937
  _globals['_READINESSRESPONSE']._serialized_end=1056
  _globals['_REGION']._serialized_start=1058
  _globals['_REGION']._serialized_end=1127
  _globals['_MODELVERSION']._serialized_start=1130
  _globals['_MODELVERSION']._serialized_end=1353
  _globals['_MODEL']._serialized_start=1356
  _globals['_MODEL']._serialized_end=3103
  _globals['_MODEL_STATS']._serialized_start=2683
  _globals['_MODEL_STATS']._serialized_end=2802
  _globals['_MODEL_VISIBILITY']._serialized_start=2804
  _globals['_MODEL_VISIBILITY']._serialized_end=2891
  _globals['_LISTMODELSREQUEST']._serialized_start=3106
  _globals['_LISTMODELSREQUEST']._serialized_end=3553
  _globals['_LISTMODELSRESPONSE']._serialized_start=3556
  _globals['_LISTMODELSRESPONSE']._serialized_end=3714
  _globals['_LOOKUPMODELREQUEST']._serialized_start=3716
  _globals['_LOOKUPMODELREQUEST']._serialized_end=3837
  _globals['_LOOKUPMODELRESPONSE']._serialized_start=3839
  _globals['_LOOKUPMODELRESPONSE']._serialized_end=3915
  _globals['_LISTNAMESPACEMODELSREQUEST']._serialized_start=3918
  _globals['_LISTNAMESPACEMODELSREQUEST']._serialized_end=4414
  _globals['_LISTNAMESPACEMODELSRESPONSE']._serialized_start=4417
  _globals['_LISTNAMESPACEMODELSRESPONSE']._serialized_end=4584
  _globals['_CREATENAMESPACEMODELREQUEST']._serialized_start=4586
  _globals['_CREATENAMESPACEMODELREQUEST']._serialized_end=4705
  _globals['_CREATENAMESPACEMODELRESPONSE']._serialized_start=4707
  _globals['_CREATENAMESPACEMODELRESPONSE']._serialized_end=4792
  _globals['_GETNAMESPACEMODELREQUEST']._serialized_start=4795
  _globals['_GETNAMESPACEMODELREQUEST']._serialized_end=4959
  _globals['_GETNAMESPACEMODELRESPONSE']._serialized_start=4961
  _globals['_GETNAMESPACEMODELRESPONSE']._serialized_end=5043
  _globals['_UPDATENAMESPACEMODELREQUEST']._serialized_start=5046
  _globals['_UPDATENAMESPACEMODELREQUEST']._serialized_end=5268
  _globals['_UPDATENAMESPACEMODELRESPONSE']._serialized_start=5270
  _globals['_UPDATENAMESPACEMODELRESPONSE']._serialized_end=5355
  _globals['_DELETENAMESPACEMODELREQUEST']._serialized_start=5357
  _globals['_DELETENAMESPACEMODELREQUEST']._serialized_end=5458
  _globals['_DELETENAMESPACEMODELRESPONSE']._serialized_start=5460
  _globals['_DELETENAMESPACEMODELRESPONSE']._serialized_end=5490
  _globals['_RENAMENAMESPACEMODELREQUEST']._serialized_start=5493
  _globals['_RENAMENAMESPACEMODELREQUEST']._serialized_end=5633
  _globals['_RENAMENAMESPACEMODELRESPONSE']._serialized_start=5635
  _globals['_RENAMENAMESPACEMODELRESPONSE']._serialized_end=5720
  _globals['_WATCHNAMESPACEMODELREQUEST']._serialized_start=5723
  _globals['_WATCHNAMESPACEMODELREQUEST']._serialized_end=5854
  _globals['_WATCHNAMESPACEMODELRESPONSE']._serialized_start=5856
  _globals['_WATCHNAMESPACEMODELRESPONSE']._serialized_end=5977
  _globals['_WATCHNAMESPACELATESTMODELREQUEST']._serialized_start=5979
  _globals['_WATCHNAMESPACELATESTMODELREQUEST']._serialized_end=6085
  _globals['_WATCHNAMESPACELATESTMODELRESPONSE']._serialized_start=6087
  _globals['_WATCHNAMESPACELATESTMODELRESPONSE']._serialized_end=6214
  _globals['_LISTNAMESPACEMODELVERSIONSREQUEST']._serialized_start=6217
  _globals['_LISTNAMESPACEMODELVERSIONSREQUEST']._serialized_end=6416
  _globals['_LISTNAMESPACEMODELVERSIONSRESPONSE']._serialized_start=6419
  _globals['_LISTNAMESPACEMODELVERSIONSRESPONSE']._serialized_end=6618
  _globals['_DELETENAMESPACEMODELVERSIONREQUEST']._serialized_start=6621
  _globals['_DELETENAMESPACEMODELVERSIONREQUEST']._serialized_end=6760
  _globals['_DELETENAMESPACEMODELVERSIONRESPONSE']._serialized_start=6762
  _globals['_DELETENAMESPACEMODELVERSIONRESPONSE']._serialized_end=6799
  _globals['_TRIGGERNAMESPACEMODELREQUEST']._serialized_start=6802
  _globals['_TRIGGERNAMESPACEMODELREQUEST']._serialized_end=7004
  _globals['_TRIGGERNAMESPACEMODELRESPONSE']._serialized_start=7007
  _globals['_TRIGGERNAMESPACEMODELRESPONSE']._serialized_end=7161
  _globals['_TRIGGERASYNCNAMESPACEMODELREQUEST']._serialized_start=7164
  _globals['_TRIGGERASYNCNAMESPACEMODELREQUEST']._serialized_end=7371
  _globals['_TRIGGERASYNCNAMESPACEMODELRESPONSE']._serialized_start=7373
  _globals['_TRIGGERASYNCNAMESPACEMODELRESPONSE']._serialized_end=7475
  _globals['_TRIGGERNAMESPACELATESTMODELREQUEST']._serialized_start=7478
  _globals['_TRIGGERNAMESPACELATESTMODELREQUEST']._serialized_end=7655
  _globals['_TRIGGERNAMESPACELATESTMODELRESPONSE']._serialized_start=7658
  _globals['_TRIGGERNAMESPACELATESTMODELRESPONSE']._serialized_end=7818
  _globals['_TRIGGERASYNCNAMESPACELATESTMODELREQUEST']._serialized_start=7821
  _globals['_TRIGGERASYNCNAMESPACELATESTMODELREQUEST']._serialized_end=8003
  _globals['_TRIGGERASYNCNAMESPACELATESTMODELRESPONSE']._serialized_start=8005
  _globals['_TRIGGERASYNCNAMESPACELATESTMODELRESPONSE']._serialized_end=8113
  _globals['_TRIGGERNAMESPACEMODELBINARYFILEUPLOADREQUEST']._serialized_start=8116
  _globals['_TRIGGERNAMESPACEMODELBINARYFILEUPLOADREQUEST']._serialized_end=8332
  _globals['_TRIGGERNAMESPACEMODELBINARYFILEUPLOADRESPONSE']._serialized_start=8335
  _globals['_TRIGGERNAMESPACEMODELBINARYFILEUPLOADRESPONSE']._serialized_end=8511
  _globals['_TRIGGERNAMESPACELATESTMODELBINARYFILEUPLOADREQUEST']._serialized_start=8514
  _globals['_TRIGGERNAMESPACELATESTMODELBINARYFILEUPLOADREQUEST']._serialized_end=8705
  _globals['_TRIGGERNAMESPACELATESTMODELBINARYFILEUPLOADRESPONSE']._serialized_start=8708
  _globals['_TRIGGERNAMESPACELATESTMODELBINARYFILEUPLOADRESPONSE']._serialized_end=8884
  _globals['_GETNAMESPACELATESTMODELOPERATIONREQUEST']._serialized_start=8887
  _globals['_GETNAMESPACELATESTMODELOPERATIONREQUEST']._serialized_end=9066
  _globals['_GETNAMESPACELATESTMODELOPERATIONRESPONSE']._serialized_start=9068
  _globals['_GETNAMESPACELATESTMODELOPERATIONRESPONSE']._serialized_end=9176
  _globals['_GETNAMESPACEMODELOPERATIONREQUEST']._serialized_start=9179
  _globals['_GETNAMESPACEMODELOPERATIONREQUEST']._serialized_end=9383
  _globals['_GETNAMESPACEMODELOPERATIONRESPONSE']._serialized_start=9385
  _globals['_GETNAMESPACEMODELOPERATIONRESPONSE']._serialized_end=9482
  _globals['_DEPLOYNAMESPACEMODELADMINREQUEST']._serialized_start=9485
  _globals['_DEPLOYNAMESPACEMODELADMINREQUEST']._serialized_end=9651
  _globals['_DEPLOYNAMESPACEMODELADMINRESPONSE']._serialized_start=9653
  _globals['_DEPLOYNAMESPACEMODELADMINRESPONSE']._serialized_end=9694
  _globals['_UNDEPLOYNAMESPACEMODELADMINREQUEST']._serialized_start=9697
  _globals['_UNDEPLOYNAMESPACEMODELADMINREQUEST']._serialized_end=9865
  _globals['_UNDEPLOYNAMESPACEMODELADMINRESPONSE']._serialized_start=9867
  _globals['_UNDEPLOYNAMESPACEMODELADMINRESPONSE']._serialized_end=9910
  _globals['_CREATEUSERMODELREQUEST']._serialized_start=9913
  _globals['_CREATEUSERMODELREQUEST']._serialized_end=10061
  _globals['_CREATEUSERMODELRESPONSE']._serialized_start=10063
  _globals['_CREATEUSERMODELRESPONSE']._serialized_end=10143
  _globals['_LISTUSERMODELSREQUEST']._serialized_start=10146
  _globals['_LISTUSERMODELSREQUEST']._serialized_end=10671
  _globals['_LISTUSERMODELSRESPONSE']._serialized_start=10674
  _globals['_LISTUSERMODELSRESPONSE']._serialized_end=10836
  _globals['_GETUSERMODELREQUEST']._serialized_start=10839
  _globals['_GETUSERMODELREQUEST']._serialized_end=11002
  _globals['_GETUSERMODELRESPONSE']._serialized_start=11004
  _globals['_GETUSERMODELRESPONSE']._serialized_end=11081
  _globals['_UPDATEUSERMODELREQUEST']._serialized_start=11084
  _globals['_UPDATEUSERMODELREQUEST']._serialized_end=11229
  _globals['_UPDATEUSERMODELRESPONSE']._serialized_start=11231
  _globals['_UPDATEUSERMODELRESPONSE']._serialized_end=11311
  _globals['_DELETEUSERMODELREQUEST']._serialized_start=11313
  _globals['_DELETEUSERMODELREQUEST']._serialized_end=11413
  _globals['_DELETEUSERMODELRESPONSE']._serialized_start=11415
  _globals['_DELETEUSERMODELRESPONSE']._serialized_end=11440
  _globals['_RENAMEUSERMODELREQUEST']._serialized_start=11443
  _globals['_RENAMEUSERMODELREQUEST']._serialized_end=11582
  _globals['_RENAMEUSERMODELRESPONSE']._serialized_start=11584
  _globals['_RENAMEUSERMODELRESPONSE']._serialized_end=11664
  _globals['_WATCHUSERMODELREQUEST']._serialized_start=11667
  _globals['_WATCHUSERMODELREQUEST']._serialized_end=11797
  _globals['_WATCHUSERMODELRESPONSE']._serialized_start=11799
  _globals['_WATCHUSERMODELRESPONSE']._serialized_end=11915
  _globals['_WATCHUSERLATESTMODELREQUEST']._serialized_start=11917
  _globals['_WATCHUSERLATESTMODELREQUEST']._serialized_end=12022
  _globals['_WATCHUSERLATESTMODELRESPONSE']._serialized_start=12024
  _globals['_WATCHUSERLATESTMODELRESPONSE']._serialized_end=12146
  _globals['_LISTUSERMODELVERSIONSREQUEST']._serialized_start=12149
  _globals['_LISTUSERMODELVERSIONSREQUEST']._serialized_end=12347
  _globals['_LISTUSERMODELVERSIONSRESPONSE']._serialized_start=12350
  _globals['_LISTUSERMODELVERSIONSRESPONSE']._serialized_end=12544
  _globals['_DELETEUSERMODELVERSIONREQUEST']._serialized_start=12547
  _globals['_DELETEUSERMODELVERSIONREQUEST']._serialized_end=12685
  _globals['_DELETEUSERMODELVERSIONRESPONSE']._serialized_start=12687
  _globals['_DELETEUSERMODELVERSIONRESPONSE']._serialized_end=12719
  _globals['_TRIGGERUSERMODELREQUEST']._serialized_start=12722
  _globals['_TRIGGERUSERMODELREQUEST']._serialized_end=12923
  _globals['_TRIGGERUSERMODELRESPONSE']._serialized_start=12926
  _globals['_TRIGGERUSERMODELRESPONSE']._serialized_end=13075
  _globals['_TRIGGERASYNCUSERMODELREQUEST']._serialized_start=13078
  _globals['_TRIGGERASYNCUSERMODELREQUEST']._serialized_end=13284
  _globals['_TRIGGERASYNCUSERMODELRESPONSE']._serialized_start=13286
  _globals['_TRIGGERASYNCUSERMODELRESPONSE']._serialized_end=13383
  _globals['_TRIGGERUSERLATESTMODELREQUEST']._serialized_start=13386
  _globals['_TRIGGERUSERLATESTMODELREQUEST']._serialized_end=13562
  _globals['_TRIGGERUSERLATESTMODELRESPONSE']._serialized_start=13565
  _globals['_TRIGGERUSERLATESTMODELRESPONSE']._serialized_end=13720
  _globals['_TRIGGERASYNCUSERLATESTMODELREQUEST']._serialized_start=13723
  _globals['_TRIGGERASYNCUSERLATESTMODELREQUEST']._serialized_end=13904
  _globals['_TRIGGERASYNCUSERLATESTMODELRESPONSE']._serialized_start=13906
  _globals['_TRIGGERASYNCUSERLATESTMODELRESPONSE']._serialized_end=14009
  _globals['_TRIGGERUSERMODELBINARYFILEUPLOADREQUEST']._serialized_start=14012
  _globals['_TRIGGERUSERMODELBINARYFILEUPLOADREQUEST']._serialized_end=14229
  _globals['_TRIGGERUSERMODELBINARYFILEUPLOADRESPONSE']._serialized_start=14232
  _globals['_TRIGGERUSERMODELBINARYFILEUPLOADRESPONSE']._serialized_end=14403
  _globals['_CREATEORGANIZATIONMODELREQUEST']._serialized_start=14406
  _globals['_CREATEORGANIZATIONMODELREQUEST']._serialized_end=14570
  _globals['_CREATEORGANIZATIONMODELRESPONSE']._serialized_start=14572
  _globals['_CREATEORGANIZATIONMODELRESPONSE']._serialized_end=14660
  _globals['_LISTORGANIZATIONMODELSREQUEST']._serialized_start=14663
  _globals['_LISTORGANIZATIONMODELSREQUEST']._serialized_end=15204
  _globals['_LISTORGANIZATIONMODELSRESPONSE']._serialized_start=15207
  _globals['_LISTORGANIZATIONMODELSRESPONSE']._serialized_end=15377
  _globals['_GETORGANIZATIONMODELREQUEST']._serialized_start=15380
  _globals['_GETORGANIZATIONMODELREQUEST']._serialized_end=15559
  _globals['_GETORGANIZATIONMODELRESPONSE']._serialized_start=15561
  _globals['_GETORGANIZATIONMODELRESPONSE']._serialized_end=15646
  _globals['_UPDATEORGANIZATIONMODELREQUEST']._serialized_start=15649
  _globals['_UPDATEORGANIZATIONMODELREQUEST']._serialized_end=15802
  _globals['_UPDATEORGANIZATIONMODELRESPONSE']._serialized_start=15804
  _globals['_UPDATEORGANIZATIONMODELRESPONSE']._serialized_end=15892
  _globals['_DELETEORGANIZATIONMODELREQUEST']._serialized_start=15894
  _globals['_DELETEORGANIZATIONMODELREQUEST']._serialized_end=16010
  _globals['_DELETEORGANIZATIONMODELRESPONSE']._serialized_start=16012
  _globals['_DELETEORGANIZATIONMODELRESPONSE']._serialized_end=16045
  _globals['_RENAMEORGANIZATIONMODELREQUEST']._serialized_start=16048
  _globals['_RENAMEORGANIZATIONMODELREQUEST']._serialized_end=16203
  _globals['_RENAMEORGANIZATIONMODELRESPONSE']._serialized_start=16205
  _globals['_RENAMEORGANIZATIONMODELRESPONSE']._serialized_end=16293
  _globals['_WATCHORGANIZATIONMODELREQUEST']._serialized_start=16296
  _globals['_WATCHORGANIZATIONMODELREQUEST']._serialized_end=16442
  _globals['_WATCHORGANIZATIONMODELRESPONSE']._serialized_start=16444
  _globals['_WATCHORGANIZATIONMODELRESPONSE']._serialized_end=16568
  _globals['_WATCHORGANIZATIONLATESTMODELREQUEST']._serialized_start=16570
  _globals['_WATCHORGANIZATIONLATESTMODELREQUEST']._serialized_end=16691
  _globals['_WATCHORGANIZATIONLATESTMODELRESPONSE']._serialized_start=16694
  _globals['_WATCHORGANIZATIONLATESTMODELRESPONSE']._serialized_end=16824
  _globals['_LISTORGANIZATIONMODELVERSIONSREQUEST']._serialized_start=16827
  _globals['_LISTORGANIZATIONMODELVERSIONSREQUEST']._serialized_end=17041
  _globals['_LISTORGANIZATIONMODELVERSIONSRESPONSE']._serialized_start=17044
  _globals['_LISTORGANIZATIONMODELVERSIONSRESPONSE']._serialized_end=17246
  _globals['_DELETEORGANIZATIONMODELVERSIONREQUEST']._serialized_start=17249
  _globals['_DELETEORGANIZATIONMODELVERSIONREQUEST']._serialized_end=17403
  _globals['_DELETEORGANIZATIONMODELVERSIONRESPONSE']._serialized_start=17405
  _globals['_DELETEORGANIZATIONMODELVERSIONRESPONSE']._serialized_end=17445
  _globals['_TRIGGERORGANIZATIONMODELREQUEST']._serialized_start=17448
  _globals['_TRIGGERORGANIZATIONMODELREQUEST']._serialized_end=17665
  _globals['_TRIGGERORGANIZATIONMODELRESPONSE']._serialized_start=17668
  _globals['_TRIGGERORGANIZATIONMODELRESPONSE']._serialized_end=17825
  _globals['_TRIGGERASYNCORGANIZATIONMODELREQUEST']._serialized_start=17828
  _globals['_TRIGGERASYNCORGANIZATIONMODELREQUEST']._serialized_end=18050
  _globals['_TRIGGERASYNCORGANIZATIONMODELRESPONSE']._serialized_start=18052
  _globals['_TRIGGERASYNCORGANIZATIONMODELRESPONSE']._serialized_end=18157
  _globals['_TRIGGERORGANIZATIONLATESTMODELREQUEST']._serialized_start=18160
  _globals['_TRIGGERORGANIZATIONLATESTMODELREQUEST']._serialized_end=18352
  _globals['_TRIGGERORGANIZATIONLATESTMODELRESPONSE']._serialized_start=18355
  _globals['_TRIGGERORGANIZATIONLATESTMODELRESPONSE']._serialized_end=18518
  _globals['_TRIGGERASYNCORGANIZATIONLATESTMODELREQUEST']._serialized_start=18521
  _globals['_TRIGGERASYNCORGANIZATIONLATESTMODELREQUEST']._serialized_end=18718
  _globals['_TRIGGERASYNCORGANIZATIONLATESTMODELRESPONSE']._serialized_start=18720
  _globals['_TRIGGERASYNCORGANIZATIONLATESTMODELRESPONSE']._serialized_end=18831
  _globals['_TRIGGERORGANIZATIONMODELBINARYFILEUPLOADREQUEST']._serialized_start=18834
  _globals['_TRIGGERORGANIZATIONMODELBINARYFILEUPLOADREQUEST']._serialized_end=19067
  _globals['_TRIGGERORGANIZATIONMODELBINARYFILEUPLOADRESPONSE']._serialized_start=19070
  _globals['_TRIGGERORGANIZATIONMODELBINARYFILEUPLOADRESPONSE']._serialized_end=19238
  _globals['_GETMODELOPERATIONREQUEST']._serialized_start=19241
  _globals['_GETMODELOPERATIONREQUEST']._serialized_end=19375
  _globals['_GETMODELOPERATIONRESPONSE']._serialized_start=19377
  _globals['_GETMODELOPERATIONRESPONSE']._serialized_end=19470
  _globals['_LATESTOPERATION']._serialized_start=19473
  _globals['_LATESTOPERATION']._serialized_end=19659
  _globals['_GETUSERLATESTMODELOPERATIONREQUEST']._serialized_start=19662
  _globals['_GETUSERLATESTMODELOPERATIONREQUEST']._serialized_end=19840
  _globals['_GETUSERLATESTMODELOPERATIONRESPONSE']._serialized_start=19842
  _globals['_GETUSERLATESTMODELOPERATIONRESPONSE']._serialized_end=19945
  _globals['_GETORGANIZATIONLATESTMODELOPERATIONREQUEST']._serialized_start=19948
  _globals['_GETORGANIZATIONLATESTMODELOPERATIONREQUEST']._serialized_end=20142
  _globals['_GETORGANIZATIONLATESTMODELOPERATIONRESPONSE']._serialized_start=20144
  _globals['_GETORGANIZATIONLATESTMODELOPERATIONRESPONSE']._serialized_end=20255
  _globals['_LISTAVAILABLEREGIONSREQUEST']._serialized_start=20257
  _globals['_LISTAVAILABLEREGIONSREQUEST']._serialized_end=20286
  _globals['_LISTAVAILABLEREGIONSRESPONSE']._serialized_start=20288
  _globals['_LISTAVAILABLEREGIONSRESPONSE']._serialized_end=20378
  _globals['_LISTMODELSADMINREQUEST']._serialized_start=20381
  _globals['_LISTMODELSADMINREQUEST']._serialized_end=20687
  _globals['_LISTMODELSADMINRESPONSE']._serialized_start=20690
  _globals['_LISTMODELSADMINRESPONSE']._serialized_end=20838
  _globals['_LOOKUPMODELADMINREQUEST']._serialized_start=20840
  _globals['_LOOKUPMODELADMINREQUEST']._serialized_end=20966
  _globals['_LOOKUPMODELADMINRESPONSE']._serialized_start=20968
  _globals['_LOOKUPMODELADMINRESPONSE']._serialized_end=21044
  _globals['_DEPLOYUSERMODELADMINREQUEST']._serialized_start=21047
  _globals['_DEPLOYUSERMODELADMINREQUEST']._serialized_end=21218
  _globals['_DEPLOYUSERMODELADMINRESPONSE']._serialized_start=21220
  _globals['_DEPLOYUSERMODELADMINRESPONSE']._serialized_end=21256
  _globals['_DEPLOYORGANIZATIONMODELADMINREQUEST']._serialized_start=21259
  _globals['_DEPLOYORGANIZATIONMODELADMINREQUEST']._serialized_end=21446
  _globals['_DEPLOYORGANIZATIONMODELADMINRESPONSE']._serialized_start=21448
  _globals['_DEPLOYORGANIZATIONMODELADMINRESPONSE']._serialized_end=21486
  _globals['_UNDEPLOYUSERMODELADMINREQUEST']._serialized_start=21489
  _globals['_UNDEPLOYUSERMODELADMINREQUEST']._serialized_end=21662
  _globals['_UNDEPLOYUSERMODELADMINRESPONSE']._serialized_start=21664
  _globals['_UNDEPLOYUSERMODELADMINRESPONSE']._serialized_end=21702
  _globals['_UNDEPLOYORGANIZATIONMODELADMINREQUEST']._serialized_start=21705
  _globals['_UNDEPLOYORGANIZATIONMODELADMINREQUEST']._serialized_end=21894
  _globals['_UNDEPLOYORGANIZATIONMODELADMINRESPONSE']._serialized_start=21896
  _globals['_UNDEPLOYORGANIZATIONMODELADMINRESPONSE']._serialized_end=21936
  _globals['_MODELRUN']._serialized_start=21939
  _globals['_MODELRUN']._serialized_end=22791
  _globals['_LISTMODELRUNSREQUEST']._serialized_start=22794
  _globals['_LISTMODELRUNSREQUEST']._serialized_end=23081
  _globals['_LISTMODELRUNSBYCREDITOWNERREQUEST']._serialized_start=23084
  _globals['_LISTMODELRUNSBYCREDITOWNERREQUEST']._serialized_end=23433
  _globals['_LISTMODELRUNSRESPONSE']._serialized_start=23436
  _globals['_LISTMODELRUNSRESPONSE']._serialized_end=23610
  _globals['_LISTMODELRUNSBYCREDITOWNERRESPONSE']._serialized_start=23613
  _globals['_LISTMODELRUNSBYCREDITOWNERRESPONSE']._serialized_end=23800
# @@protoc_insertion_point(module_scope)
